@@ -22,9 +22,10 @@
 
 #include <cassert>
 
+#include "bbdo/neb.pb.h"
+#include "com/centreon/broker/bam/impact_values.hh"
 #include "com/centreon/broker/bam/kpi.hh"
 #include "com/centreon/broker/config/applier/state.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/neb/downtime.hh"
 #include "com/centreon/broker/neb/service_status.hh"
 
@@ -46,19 +47,23 @@ static bool time_is_undefined(uint64_t t) {
 /**
  *  Constructor.
  *
+ *  @param[in] id the id of this ba.
  *  @param[in] host_id the id of the associated host.
  *  @param[in] service_id the id of the associated service.
- *  @param[in] id the id of this ba.
+ *  @param[in] source Source, i.e. the type of service.
  *  @param[in] generate_virtual_status  Whether or not the BA object
  *                                      should generate statuses of
  *                                      virtual hosts and services.
+ *  @param[in] logger The logger used in this ba.
  */
 ba::ba(uint32_t id,
        uint32_t host_id,
        uint32_t service_id,
        configuration::ba::state_source source,
-       bool generate_virtual_status)
-    : _id(id),
+       bool generate_virtual_status,
+       const std::shared_ptr<spdlog::logger>& logger)
+    : computable(logger),
+      _id(id),
       _state_source(source),
       _host_id(host_id),
       _service_id(service_id),
@@ -186,26 +191,25 @@ void ba::remove_impact(std::shared_ptr<kpi> const& impact) {
 void ba::set_initial_event(const pb_ba_event& event) {
   const BaEvent& data = event.obj();
   SPDLOG_LOGGER_TRACE(
-      log_v2::bam(),
+      _logger,
       "BAM: ba initial event set (ba_id:{}, start_time:{}, end_time:{}, "
       "in_downtime:{}, status:{})",
       data.ba_id(), data.start_time(), data.end_time(), data.in_downtime(),
-      data.status());
+      static_cast<uint32_t>(data.status()));
 
   if (!_event) {
     _event = std::make_shared<pb_ba_event>(event);
     _in_downtime = data.in_downtime();
-    SPDLOG_LOGGER_TRACE(log_v2::bam(), "ba initial event downtime: {}",
-                        _in_downtime);
+    SPDLOG_LOGGER_TRACE(_logger, "ba initial event downtime: {}", _in_downtime);
     _last_kpi_update = data.start_time();
     _initial_events.push_back(_event);
   } else {
     SPDLOG_LOGGER_ERROR(
-        log_v2::bam(),
+        _logger,
         "BAM: impossible to set ba initial event (ba_id:{}, start_time:{}, "
         "end_time:{}, in_downtime:{}, status:{}): event already defined",
         data.ba_id(), data.start_time(), data.end_time(), data.in_downtime(),
-        data.status());
+        static_cast<uint32_t>(data.status()));
   }
 }
 
@@ -252,7 +256,7 @@ void ba::visit(io::stream* visitor) {
     com::centreon::broker::bam::state hard_state(get_state_hard());
     bool state_changed(false);
     if (!_event) {
-      SPDLOG_LOGGER_TRACE(log_v2::bam(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "BAM: ba::visit no event => creation of one");
       if (_last_kpi_update.is_null())
         _last_kpi_update = time(nullptr);
@@ -263,12 +267,12 @@ void ba::visit(io::stream* visitor) {
              com::centreon::broker::State(hard_state) !=
                  _event->obj().status()) {
       SPDLOG_LOGGER_TRACE(
-          log_v2::bam(),
+          _logger,
           "BAM: ba current event needs update? downtime?: {}, state?: {} ; "
           "dt:{}, state:{} ",
           _in_downtime != _event->obj().in_downtime(),
           com::centreon::broker::State(hard_state) != _event->obj().status(),
-          _in_downtime, hard_state);
+          _in_downtime, static_cast<uint32_t>(hard_state));
       state_changed = true;
       _event->mut_obj().set_end_time(_last_kpi_update);
       visitor->write(std::static_pointer_cast<io::data>(_event));
@@ -298,11 +302,10 @@ void ba::visit(io::stream* visitor) {
  */
 void ba::service_update(const std::shared_ptr<neb::downtime>& dt,
                         io::stream* visitor) {
-  (void)visitor;
   if (dt->host_id == _host_id && dt->service_id == _service_id) {
     // Log message.
     SPDLOG_LOGGER_DEBUG(
-        log_v2::bam(),
+        _logger,
         "BAM: BA {} '{}' is getting notified of a downtime on its service ({}, "
         "{})",
         _id, _name, _host_id, _service_id);
@@ -310,7 +313,7 @@ void ba::service_update(const std::shared_ptr<neb::downtime>& dt,
     // Check if there was a change.
     bool in_downtime(dt->was_started && dt->actual_end_time.is_null());
     if (_in_downtime != in_downtime) {
-      SPDLOG_LOGGER_TRACE(log_v2::bam(), "ba: service_update downtime: {}",
+      SPDLOG_LOGGER_TRACE(_logger, "ba: service_update downtime: {}",
                           _in_downtime);
       _in_downtime = in_downtime;
 
@@ -321,7 +324,7 @@ void ba::service_update(const std::shared_ptr<neb::downtime>& dt,
     }
   } else
     SPDLOG_LOGGER_DEBUG(
-        log_v2::bam(),
+        _logger,
         "BAM: BA {} '{}' has got an invalid downtime event. This should never "
         "happen. Check your database: got (host {}, service {}) expected ({}, "
         "{})",
@@ -338,14 +341,13 @@ void ba::service_update(const std::shared_ptr<neb::downtime>& dt,
  */
 void ba::service_update(const std::shared_ptr<neb::pb_downtime>& dt,
                         io::stream* visitor) {
-  (void)visitor;
   auto& downtime = dt->obj();
   assert(downtime.host_id() == _host_id &&
          downtime.service_id() == _service_id);
 
   // Log message.
   SPDLOG_LOGGER_DEBUG(
-      log_v2::bam(),
+      _logger,
       "BAM: BA {} '{}' is getting notified of a downtime (pb) on its service "
       "({}, {})",
       _id, _name, _host_id, _service_id);
@@ -354,7 +356,7 @@ void ba::service_update(const std::shared_ptr<neb::pb_downtime>& dt,
   bool in_downtime(downtime.started() &&
                    time_is_undefined(downtime.actual_end_time()));
   if (_in_downtime != in_downtime) {
-    SPDLOG_LOGGER_TRACE(log_v2::bam(), "ba: service_update downtime: {}",
+    SPDLOG_LOGGER_TRACE(_logger, "ba: service_update downtime: {}",
                         _in_downtime);
     _in_downtime = in_downtime;
 
@@ -408,9 +410,8 @@ void ba::set_inherited_downtime(const inherited_downtime& dwn) {
  */
 void ba::_open_new_event(io::stream* visitor,
                          com::centreon::broker::bam::state service_hard_state) {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(),
-                      "new pb_ba_event on ba {} with downtime = {}", _id,
-                      _in_downtime);
+  SPDLOG_LOGGER_TRACE(_logger, "new pb_ba_event on ba {} with downtime = {}",
+                      _id, _in_downtime);
   _event = std::make_shared<pb_ba_event>();
   BaEvent& data = _event->mut_obj();
   data.set_ba_id(_id);
@@ -447,8 +448,7 @@ void ba::_commit_initial_events(io::stream* visitor) {
 void ba::_compute_inherited_downtime(io::stream* visitor) {
   // kpi downtime heritance deactived. Do nothing.
   if (_dt_behaviour != configuration::ba::dt_inherit) {
-    SPDLOG_LOGGER_TRACE(log_v2::bam(), "ba: BA {} doesn't inherite downtimes",
-                        _id);
+    SPDLOG_LOGGER_TRACE(_logger, "ba: BA {} doesn't inherite downtimes", _id);
     return;
   }
 
@@ -460,7 +460,7 @@ void ba::_compute_inherited_downtime(io::stream* visitor) {
        it != end; ++it) {
     if (!it->first->ok_state() && !it->first->in_downtime()) {
       SPDLOG_LOGGER_TRACE(
-          log_v2::bam(),
+          _logger,
           "ba: every kpi in downtime ? no, kpi {} is not ok and not in "
           "downtime",
           it->first->get_id());
@@ -476,7 +476,7 @@ void ba::_compute_inherited_downtime(io::stream* visitor) {
     _inherited_downtime = std::make_unique<pb_inherited_downtime>();
     _inherited_downtime->mut_obj().set_ba_id(_id);
     _inherited_downtime->mut_obj().set_in_downtime(true);
-    SPDLOG_LOGGER_TRACE(log_v2::bam(),
+    SPDLOG_LOGGER_TRACE(_logger,
                         "ba: inherited downtime computation downtime true");
     _in_downtime = true;
 
@@ -488,7 +488,7 @@ void ba::_compute_inherited_downtime(io::stream* visitor) {
   //         Remove the downtime.
   else if ((s_ok || !every_kpi_in_downtime) && _inherited_downtime) {
     _inherited_downtime->mut_obj().set_in_downtime(false);
-    SPDLOG_LOGGER_TRACE(log_v2::bam(),
+    SPDLOG_LOGGER_TRACE(_logger,
                         "ba: inherited downtime computation downtime false");
     _in_downtime = false;
 
@@ -497,8 +497,7 @@ void ba::_compute_inherited_downtime(io::stream* visitor) {
     _inherited_downtime.reset();
   } else
     SPDLOG_LOGGER_TRACE(
-        log_v2::bam(),
-        "ba: inherited downtime computation downtime not changed ({})",
+        _logger, "ba: inherited downtime computation downtime not changed ({})",
         _in_downtime);
 }
 
@@ -590,8 +589,7 @@ void ba::set_level_warning(double level) {
  * @param visitor The visitor to handle events.
  */
 void ba::update_from(computable* child, io::stream* visitor) {
-  auto logger = log_v2::bam();
-  logger->trace("ba::update_from (BA {})", _id);
+  _logger->trace("ba::update_from (BA {})", _id);
   // Get impact.
   impact_values new_hard_impact;
   impact_values new_soft_impact;
@@ -603,7 +601,7 @@ void ba::update_from(computable* child, io::stream* visitor) {
 
   // Logging.
   SPDLOG_LOGGER_DEBUG(
-      logger,
+      _logger,
       "BAM: BA {}, '{}' is getting notified of child update (KPI {}, impact "
       "{}, last state change {}, downtime {})",
       _id, _name, kpi_child->get_id(), new_hard_impact.get_nominal(),
@@ -614,11 +612,11 @@ void ba::update_from(computable* child, io::stream* visitor) {
     _last_kpi_update = std::max(_last_kpi_update, last_state_change);
 
   // Apply new data.
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: BA {} updated from KPI {}", _id,
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: BA {} updated from KPI {}", _id,
                       kpi_child->get_id());
   bool changed = _apply_changes(kpi_child, new_hard_impact, new_soft_impact,
                                 kpi_in_downtime);
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BA {} has changed: {}", _id, changed);
+  SPDLOG_LOGGER_TRACE(_logger, "BA {} has changed: {}", _id, changed);
 
   // Check for inherited downtimes.
   _compute_inherited_downtime(visitor);
@@ -638,7 +636,7 @@ void ba::update_from(computable* child, io::stream* visitor) {
  */
 std::string ba::object_info() const {
   return fmt::format("BA {}\nname: {}\nstate: {}\ndowntime: {}", _id, _name,
-                     get_state_hard(), _in_downtime);
+                     static_cast<uint32_t>(get_state_hard()), _in_downtime);
 }
 
 /**
@@ -653,8 +651,8 @@ void ba::dump(const std::string& filename) const {
     dump(output);
     output << "}\n";
   } else
-    log_v2::bam()->error("Unable to open the file '{}' to write BA {} info",
-                         filename, _id);
+    _logger->error("Unable to open the file '{}' to write BA {} info", filename,
+                   _id);
 }
 
 /**
