@@ -1,5 +1,5 @@
 /**
- * Copyright 2014-2023 Centreon
+ * Copyright 2014-2024 Centreon
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,18 +27,20 @@
 #include "com/centreon/broker/bam/event_cache_visitor.hh"
 #include "com/centreon/broker/config/applier/state.hh"
 #include "com/centreon/broker/exceptions/shutdown.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/misc/fifo_client.hh"
 #include "com/centreon/broker/neb/acknowledgement.hh"
 #include "com/centreon/broker/neb/downtime.hh"
 #include "com/centreon/broker/neb/service.hh"
-#include "com/centreon/broker/pool.hh"
+#include "com/centreon/common/pool.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::exceptions;
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::bam;
 using namespace com::centreon::broker::database;
 
+using log_v2 = com::centreon::common::log_v2::log_v2;
+
 /**
  *  Constructor.
  *
@@ -48,20 +50,24 @@ using namespace com::centreon::broker::database;
  *                             configuration.
  *  @param[in] cache           The persistent cache.
  */
-monitoring_stream::monitoring_stream(const std::string& ext_cmd_file,
-                                     const database_config& db_cfg,
-                                     const database_config& storage_db_cfg,
-                                     std::shared_ptr<persistent_cache> cache)
+monitoring_stream::monitoring_stream(
+    const std::string& ext_cmd_file,
+    const database_config& db_cfg,
+    const database_config& storage_db_cfg,
+    std::shared_ptr<persistent_cache> cache,
+    const std::shared_ptr<spdlog::logger>& logger)
     : io::stream("BAM"),
       _ext_cmd_file(ext_cmd_file),
+      _logger{logger},
+      _applier(_logger),
       _mysql(db_cfg.auto_commit_conf()),
       _conf_queries_per_transaction(db_cfg.get_queries_per_transaction()),
       _pending_events(0),
       _pending_request(0),
       _storage_db_cfg(storage_db_cfg),
       _cache(std::move(cache)),
-      _forced_svc_checks_timer{pool::io_context()} {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring_stream constructor");
+      _forced_svc_checks_timer{com::centreon::common::pool::io_context()} {
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring_stream constructor");
   if (!_conf_queries_per_transaction) {
     _conf_queries_per_transaction = 1;
   }
@@ -78,13 +84,13 @@ monitoring_stream::monitoring_stream(const std::string& ext_cmd_file,
  */
 monitoring_stream::~monitoring_stream() {
   // save cache
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring_stream destructor");
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring_stream destructor");
   try {
     _write_cache();
   } catch (std::exception const& e) {
-    log_v2::bam()->error("BAM: can't save cache: '{}'", e.what());
+    _logger->error("BAM: can't save cache: '{}'", e.what());
   }
-  SPDLOG_LOGGER_DEBUG(log_v2::bam(), "BAM: monitoring_stream destruction done");
+  SPDLOG_LOGGER_DEBUG(_logger, "BAM: monitoring_stream destruction done");
 }
 
 /**
@@ -96,7 +102,7 @@ int32_t monitoring_stream::flush() {
   _execute();
   _pending_request = 0;
   int retval = _pending_events;
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring_stream flush: {} events",
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring_stream flush: {} events",
                       retval);
   _pending_events = 0;
   return retval;
@@ -109,12 +115,12 @@ int32_t monitoring_stream::flush() {
  */
 int32_t monitoring_stream::stop() {
   int32_t retval = flush();
-  log_v2::core()->info("monitoring stream: stopped with {} events acknowledged",
-                       retval);
+  _logger->info("monitoring stream: stopped with {} events acknowledged",
+                retval);
   /* I want to be sure the timer is really stopped. */
   std::promise<void> p;
   {
-    log_v2::bam()->info(
+    _logger->info(
         "bam: monitoring_stream - waiting for forced service checks to be "
         "done");
     std::lock_guard<std::mutex> lck(_forced_svc_checks_m);
@@ -131,7 +137,7 @@ int32_t monitoring_stream::stop() {
   }
   p.get_future().wait();
   /* Now, it is really cancelled. */
-  log_v2::bam()->info("bam: monitoring_stream - stop finished");
+  _logger->info("bam: monitoring_stream - stop finished");
 
   return retval;
 }
@@ -140,7 +146,7 @@ int32_t monitoring_stream::stop() {
  *  Generate default state.
  */
 void monitoring_stream::initialize() {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring_stream initialize");
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring_stream initialize");
   multiplexing::publisher pblshr;
   event_cache_visitor ev_cache;
   _applier.visit(&ev_cache);
@@ -167,9 +173,9 @@ bool monitoring_stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
  *  Rebuild index and metrics cache.
  */
 void monitoring_stream::update() {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring_stream update");
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring_stream update");
   try {
-    configuration::state s;
+    configuration::state s{_logger};
     configuration::reader_v2 r(_mysql, _storage_db_cfg);
     r.read(s);
     _applier.apply(s);
@@ -321,14 +327,16 @@ struct kpi_binder {
       if (status.last_state_change() <= 0) {
         return fmt::format("({},{},{},{},1+1,NULL,{},{},{},{})",
                            status.level_acknowledgement_hard(),
-                           status.state_hard(), status.level_downtime_hard(),
+                           static_cast<uint32_t>(status.state_hard()),
+                           status.level_downtime_hard(),
                            status.level_nominal_hard(), status.last_impact(),
                            int(status.valid()), int(status.in_downtime()),
                            status.kpi_id());
       } else {
         return fmt::format(
             "({},{},{},{},1+1,{},{},{},{},{})",
-            status.level_acknowledgement_hard(), status.state_hard(),
+            status.level_acknowledgement_hard(),
+            static_cast<uint32_t>(status.state_hard()),
             status.level_downtime_hard(), status.level_nominal_hard(),
             status.last_state_change(), status.last_impact(),
             int(status.valid()), int(status.in_downtime()), status.kpi_id());
@@ -344,8 +352,8 @@ struct kpi_binder {
  *
  *  @return Number of events acknowledged.
  */
-int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring_stream write {}", *data);
+int monitoring_stream::write(const std::shared_ptr<io::data>& data) {
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring_stream write {}", *data);
   // Take this event into account.
   ++_pending_events;
 
@@ -362,7 +370,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
     }
   };
 
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: {} pending events", _pending_events);
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: {} pending events", _pending_events);
 
   // Process service status events.
   switch (data->type()) {
@@ -371,7 +379,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       std::shared_ptr<neb::service_status> ss(
           std::static_pointer_cast<neb::service_status>(data));
       SPDLOG_LOGGER_TRACE(
-          log_v2::bam(),
+          _logger,
           "BAM: processing service status (host: {}, service: {}, hard state "
           "{}, "
           "current state {})",
@@ -385,7 +393,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       auto ss = std::static_pointer_cast<neb::pb_service_status>(data);
       auto& o = ss->obj();
       SPDLOG_LOGGER_TRACE(
-          log_v2::bam(),
+          _logger,
           "BAM: processing pb service status (host: {}, service: {}, hard "
           "state {}, current state {})",
           o.host_id(), o.service_id(), o.last_hard_state(), o.state());
@@ -394,11 +402,23 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       _applier.book_service().update(ss, &ev_cache);
       ev_cache.commit_to(pblshr);
     } break;
+    case neb::pb_adaptive_service_status::static_type(): {
+      auto ss = std::static_pointer_cast<neb::pb_adaptive_service_status>(data);
+      auto& o = ss->obj();
+      SPDLOG_LOGGER_TRACE(_logger,
+                          "BAM: processing pb adaptive service status (host: "
+                          "{}, service: {})",
+                          o.host_id(), o.service_id());
+      multiplexing::publisher pblshr;
+      event_cache_visitor ev_cache;
+      _applier.book_service().update(ss, &ev_cache);
+      ev_cache.commit_to(pblshr);
+    } break;
     case neb::pb_service::static_type(): {
       auto s = std::static_pointer_cast<neb::pb_service>(data);
       auto& o = s->obj();
       SPDLOG_LOGGER_TRACE(
-          log_v2::bam(),
+          _logger,
           "BAM: processing pb service (host: {}, service: {}, hard "
           "state {}, current state {})",
           o.host_id(), o.service_id(), o.last_hard_state(), o.state());
@@ -410,7 +430,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
     case neb::pb_acknowledgement::static_type(): {
       std::shared_ptr<neb::pb_acknowledgement> ack(
           std::static_pointer_cast<neb::pb_acknowledgement>(data));
-      SPDLOG_LOGGER_TRACE(log_v2::bam(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "BAM: processing acknowledgement on service ({}, {})",
                           ack->obj().host_id(), ack->obj().service_id());
       multiplexing::publisher pblshr;
@@ -421,7 +441,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
     case neb::acknowledgement::static_type(): {
       std::shared_ptr<neb::acknowledgement> ack(
           std::static_pointer_cast<neb::acknowledgement>(data));
-      SPDLOG_LOGGER_TRACE(log_v2::bam(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "BAM: processing acknowledgement on service ({}, {})",
                           ack->host_id, ack->service_id);
       multiplexing::publisher pblshr;
@@ -433,7 +453,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       std::shared_ptr<neb::downtime> dt(
           std::static_pointer_cast<neb::downtime>(data));
       SPDLOG_LOGGER_TRACE(
-          log_v2::bam(),
+          _logger,
           "BAM: processing downtime ({}) on service ({}, {}) started: {}, "
           "stopped: {}",
           dt->internal_id, dt->host_id, dt->service_id, dt->was_started,
@@ -447,7 +467,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       std::shared_ptr<neb::pb_downtime> dt(
           std::static_pointer_cast<neb::pb_downtime>(data));
       auto& downtime = dt->obj();
-      SPDLOG_LOGGER_TRACE(log_v2::bam(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "BAM: processing downtime (pb) ({}) on service "
                           "({}, {}) started: {}, "
                           "stopped: {}",
@@ -473,7 +493,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
         std::pair<std::string, std::string> ba_svc_name(
             _ba_mapping.get_service(status->ba_id));
         if (ba_svc_name.first.empty() || ba_svc_name.second.empty()) {
-          log_v2::bam()->error(
+          _logger->error(
               "BAM: could not trigger check of virtual service of BA {}:"
               "host name and service description were not found",
               status->ba_id);
@@ -500,7 +520,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
         std::pair<std::string, std::string> ba_svc_name(
             _ba_mapping.get_service(status.ba_id()));
         if (ba_svc_name.first.empty() || ba_svc_name.second.empty()) {
-          log_v2::bam()->error(
+          _logger->error(
               "BAM: could not trigger check of virtual service of BA {}:"
               "host name and service description were not found",
               status.ba_id());
@@ -528,7 +548,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       inherited_downtime const& dwn =
           *std::static_pointer_cast<inherited_downtime const>(data);
       SPDLOG_LOGGER_TRACE(
-          log_v2::bam(), "BAM: processing inherited downtime (ba id {}, now {}",
+          _logger, "BAM: processing inherited downtime (ba id {}, now {}",
           dwn.ba_id, now);
       if (dwn.in_downtime)
         cmd = fmt::format(
@@ -552,8 +572,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       pb_inherited_downtime const& dwn =
           *std::static_pointer_cast<pb_inherited_downtime const>(data);
       SPDLOG_LOGGER_TRACE(
-          log_v2::bam(),
-          "BAM: processing pb inherited downtime (ba id {}, now {}",
+          _logger, "BAM: processing pb inherited downtime (ba id {}, now {}",
           dwn.obj().ba_id(), now);
       if (dwn.obj().in_downtime())
         cmd = fmt::format(
@@ -573,7 +592,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       _write_external_command(cmd);
     } break;
     case extcmd::pb_ba_info::static_type(): {
-      log_v2::bam()->info("BAM: dump BA");
+      _logger->info("BAM: dump BA");
       extcmd::pb_ba_info const& e =
           *std::static_pointer_cast<const extcmd::pb_ba_info>(data);
       auto& obj = e.obj();
@@ -581,7 +600,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
       if (ba)
         ba->dump(obj.output_file());
       else
-        log_v2::bam()->error(
+        _logger->error(
             "extcmd: Unable to get info about BA {} - it doesn't exist",
             obj.id());
     } break;
@@ -592,13 +611,13 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
   // if uncommited request, we can't yet acknowledge
   if (_pending_request) {
     if (_pending_events >= 10 * _conf_queries_per_transaction) {
-      log_v2::bam()->trace(
+      _logger->trace(
           "BAM: monitoring_stream write: too many pending events =>flush and "
           "acknowledge {} events",
           _pending_events);
       return flush();
     }
-    log_v2::bam()->trace(
+    _logger->trace(
         "BAM: monitoring_stream write: 0 events (request pending) {} to "
         "acknowledge",
         _pending_events);
@@ -606,7 +625,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
   }
   int retval = _pending_events;
   _pending_events = 0;
-  log_v2::bam()->trace("BAM: monitoring_stream write: {} events", retval);
+  _logger->trace("BAM: monitoring_stream write: {} events", retval);
   return retval;
 }
 
@@ -615,7 +634,7 @@ int monitoring_stream::write(std::shared_ptr<io::data> const& data) {
  */
 void monitoring_stream::_prepare() {
   if (_mysql.support_bulk_statement()) {
-    log_v2::bam()->trace("BAM: monitoring stream _prepare");
+    _logger->trace("BAM: monitoring stream _prepare");
     _ba_query = std::make_unique<database::bulk_or_multi>(
         _mysql,
         "UPDATE mod_bam SET "
@@ -658,7 +677,7 @@ void monitoring_stream::_prepare() {
  *  Rebuilds BA durations/availabilities from BA events.
  */
 void monitoring_stream::_rebuild() {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring stream _rebuild");
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring stream _rebuild");
   // Get the list of the BAs that should be rebuild.
   std::vector<uint32_t> bas_to_rebuild;
   {
@@ -680,7 +699,7 @@ void monitoring_stream::_rebuild() {
   if (bas_to_rebuild.empty())
     return;
 
-  SPDLOG_LOGGER_TRACE(log_v2::bam(),
+  SPDLOG_LOGGER_TRACE(_logger,
                       "BAM: rebuild asked, sending the rebuild signal");
 
   auto r{std::make_shared<rebuild>(
@@ -708,8 +727,8 @@ void monitoring_stream::_rebuild() {
 void monitoring_stream::_explicitly_send_forced_svc_checks(
     const boost::system::error_code& ec) {
   static int count = 0;
-  SPDLOG_LOGGER_DEBUG(log_v2::bam(),
-                      "BAM: time to send forced service checks {}", count++);
+  SPDLOG_LOGGER_DEBUG(_logger, "BAM: time to send forced service checks {}",
+                      count++);
   if (!ec) {
     if (_timer_forced_svc_checks.empty()) {
       std::lock_guard<std::mutex> lck(_forced_svc_checks_m);
@@ -717,17 +736,17 @@ void monitoring_stream::_explicitly_send_forced_svc_checks(
     }
     if (!_timer_forced_svc_checks.empty()) {
       std::lock_guard<std::mutex> lock(_ext_cmd_file_m);
-      log_v2::bam()->trace("opening {}", _ext_cmd_file);
+      _logger->trace("opening {}", _ext_cmd_file);
       misc::fifo_client fc(_ext_cmd_file);
-      SPDLOG_LOGGER_DEBUG(log_v2::bam(), "BAM: {} forced checks to schedule",
+      SPDLOG_LOGGER_DEBUG(_logger, "BAM: {} forced checks to schedule",
                           _timer_forced_svc_checks.size());
       for (auto& p : _timer_forced_svc_checks) {
         time_t now = time(nullptr);
         std::string cmd{fmt::format("[{}] SCHEDULE_FORCED_SVC_CHECK;{};{};{}\n",
                                     now, p.first, p.second, now)};
-        log_v2::bam()->debug("writing '{}' into {}", cmd, _ext_cmd_file);
+        _logger->debug("writing '{}' into {}", cmd, _ext_cmd_file);
         if (fc.write(cmd) < 0) {
-          log_v2::bam()->error(
+          _logger->error(
               "BAM: could not write forced service check to command file '{}'",
               _ext_cmd_file);
           _forced_svc_checks_timer.expires_after(std::chrono::seconds(5));
@@ -749,7 +768,7 @@ void monitoring_stream::_explicitly_send_forced_svc_checks(
 void monitoring_stream::_write_forced_svc_check(
     const std::string& host,
     const std::string& description) {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(),
+  SPDLOG_LOGGER_TRACE(_logger,
                       "BAM: monitoring stream _write_forced_svc_check");
   std::lock_guard<std::mutex> lck(_forced_svc_checks_m);
   _forced_svc_checks.emplace(host, description);
@@ -765,28 +784,26 @@ void monitoring_stream::_write_forced_svc_check(
  *  @param[in] cmd  Command to write to the external command pipe.
  */
 void monitoring_stream::_write_external_command(const std::string& cmd) {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(),
-                      "BAM: monitoring stream _write_external_command <<{}>>",
-                      cmd);
+  SPDLOG_LOGGER_TRACE(
+      _logger, "BAM: monitoring stream _write_external_command <<{}>>", cmd);
   std::lock_guard<std::mutex> lock(_ext_cmd_file_m);
   misc::fifo_client fc(_ext_cmd_file);
   if (fc.write(cmd) < 0) {
-    log_v2::bam()->error(
-        "BAM: could not write BA check result to command file '{}'",
-        _ext_cmd_file);
+    _logger->error("BAM: could not write BA check result to command file '{}'",
+                   _ext_cmd_file);
   } else
-    SPDLOG_LOGGER_DEBUG(log_v2::bam(), "BAM: sent external command '{}'", cmd);
+    SPDLOG_LOGGER_DEBUG(_logger, "BAM: sent external command '{}'", cmd);
 }
 
 /**
  *  Get inherited downtime from the cache.
  */
 void monitoring_stream::_read_cache() {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring stream _read_cache");
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring stream _read_cache");
   if (_cache == nullptr)
-    SPDLOG_LOGGER_DEBUG(log_v2::bam(), "BAM: no cache configured");
+    SPDLOG_LOGGER_DEBUG(_logger, "BAM: no cache configured");
   else {
-    SPDLOG_LOGGER_DEBUG(log_v2::bam(), "BAM: loading cache");
+    SPDLOG_LOGGER_DEBUG(_logger, "BAM: loading cache");
     _applier.load_from_cache(*_cache);
   }
 }
@@ -795,11 +812,11 @@ void monitoring_stream::_read_cache() {
  *  Save inherited downtime to the cache.
  */
 void monitoring_stream::_write_cache() {
-  SPDLOG_LOGGER_TRACE(log_v2::bam(), "BAM: monitoring stream _write_cache");
+  SPDLOG_LOGGER_TRACE(_logger, "BAM: monitoring stream _write_cache");
   if (_cache == nullptr)
-    SPDLOG_LOGGER_DEBUG(log_v2::bam(), "BAM: no cache configured");
+    SPDLOG_LOGGER_DEBUG(_logger, "BAM: no cache configured");
   else {
-    SPDLOG_LOGGER_DEBUG(log_v2::bam(), "BAM: saving cache");
+    SPDLOG_LOGGER_DEBUG(_logger, "BAM: saving cache");
     _applier.save_to_cache(*_cache);
   }
 }
