@@ -17,6 +17,8 @@
  */
 
 #include "com/centreon/broker/multiplexing/muxer.hh"
+#include <absl/synchronization/mutex.h>
+#include <absl/time/time.h>
 
 #include <cassert>
 
@@ -24,16 +26,18 @@
 #include "com/centreon/broker/config/applier/state.hh"
 #include "com/centreon/broker/exceptions/shutdown.hh"
 #include "com/centreon/broker/io/events.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/misc/misc.hh"
 #include "com/centreon/broker/misc/string.hh"
 #include "com/centreon/broker/multiplexing/engine.hh"
+#include "com/centreon/common/pool.hh"
 #include "com/centreon/common/time.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::multiplexing;
+using log_v2 = com::centreon::common::log_v2::log_v2;
 
-static std::mutex _add_bench_point_m;
+static absl::Mutex _add_bench_point_m;
 /**
  * @brief add a bench point to pb_bench event
  * as several muxers can update it at the same time, it's protected by a mutex
@@ -41,10 +45,11 @@ static std::mutex _add_bench_point_m;
  * @param event
  * @param tp_name
  */
-void add_bench_point(bbdo::pb_bench& event,
-                     const std::string& muxer_name,
-                     const char* funct_name) {
-  std::lock_guard<std::mutex> l(_add_bench_point_m);
+static void add_bench_point(bbdo::pb_bench& event,
+                            const std::string& muxer_name,
+                            const char* funct_name)
+    ABSL_LOCKS_EXCLUDED(_add_bench_point_m) {
+  absl::MutexLock lck(&_add_bench_point_m);
   com::centreon::broker::TimePoint* muxer_tp = event.mut_obj().add_points();
   muxer_tp->set_name(muxer_name);
   muxer_tp->set_function(funct_name);
@@ -54,7 +59,7 @@ void add_bench_point(bbdo::pb_bench& event,
 
 uint32_t muxer::_event_queue_max_size = std::numeric_limits<uint32_t>::max();
 
-std::mutex muxer::_running_muxers_m;
+absl::Mutex muxer::_running_muxers_m;
 absl::flat_hash_map<std::string, std::weak_ptr<muxer>> muxer::_running_muxers;
 
 /**
@@ -86,11 +91,12 @@ muxer::muxer(std::string name,
       _persistent(persistent),
       _events_size{0u},
       _center{stats::center::instance_ptr()},
-      _last_stats{std::time(nullptr)} {
+      _last_stats{std::time(nullptr)},
+      _logger{log_v2::instance().get(log_v2::CORE)} {
+  absl::SetMutexDeadlockDetectionMode(absl::OnDeadlockCycle::kAbort);
+  absl::EnableMutexInvariantDebugging(true);
   // Load head queue file back in memory.
-  DEBUG(fmt::format("CONSTRUCTOR muxer {:p} {}", static_cast<void*>(this),
-                    _name));
-  std::lock_guard<std::mutex> lck(_mutex);
+  absl::MutexLock lck(&_events_m);
   if (_persistent) {
     try {
       auto mf{std::make_unique<persistent_file>(memory_file(_name), nullptr)};
@@ -99,7 +105,7 @@ muxer::muxer(std::string name,
         e.reset();
         mf->read(e, 0);
         if (e) {
-          _events.push_back(e);
+          _events.push_back(std::move(e));
           ++_events_size;
         }
       }
@@ -123,7 +129,7 @@ muxer::muxer(std::string name,
       _get_event_from_file(e);
       if (!e)
         break;
-      _events.push_back(e);
+      _events.push_back(std::move(e));
       ++_events_size;
     } while (_events_size < event_queue_max_size());
   } catch (const exceptions::shutdown& e) {
@@ -135,7 +141,7 @@ muxer::muxer(std::string name,
 
   // Log messages.
   SPDLOG_LOGGER_INFO(
-      log_v2::core(),
+      _logger,
       "multiplexing: '{}' starts with {} in queue and the queue file is {}",
       _name, _events_size, _file ? "enable" : "disable");
 }
@@ -162,25 +168,28 @@ std::shared_ptr<muxer> muxer::create(std::string name,
                                      bool persistent) {
   std::shared_ptr<muxer> retval;
   {
-    std::lock_guard<std::mutex> lck(_running_muxers_m);
+    absl::MutexLock lck(&_running_muxers_m);
     absl::erase_if(_running_muxers,
                    [](const std::pair<std::string, std::weak_ptr<muxer>>& p) {
                      return p.second.expired();
                    });
     retval = _running_muxers[name].lock();
     if (retval) {
-      log_v2::config()->debug("muxer: muxer '{}' already exists, reusing it",
-                              name);
+      log_v2::instance()
+          .get(log_v2::CONFIG)
+          ->debug("muxer: muxer '{}' already exists, reusing it", name);
       retval->set_read_filter(r_filter);
       retval->set_write_filter(w_filter);
-      SPDLOG_LOGGER_INFO(log_v2::core(),
+      SPDLOG_LOGGER_INFO(log_v2::instance().get(log_v2::CORE),
                          "multiplexing: reuse '{}' starts with {} in queue and "
                          "the queue file is {}",
                          name, retval->_events_size,
                          retval->_file ? "enable" : "disable");
 
     } else {
-      log_v2::config()->debug("muxer: muxer '{}' unknown, creating it", name);
+      log_v2::instance()
+          .get(log_v2::CONFIG)
+          ->debug("muxer: muxer '{}' unknown, creating it", name);
       retval = std::shared_ptr<muxer>(
           new muxer(name, parent, r_filter, w_filter, persistent));
       _running_muxers[name] = retval;
@@ -195,16 +204,19 @@ std::shared_ptr<muxer> muxer::create(std::string name,
  *  Destructor.
  */
 muxer::~muxer() noexcept {
-  unsubscribe();
   {
-    std::lock_guard<std::mutex> lock(_mutex);
-    SPDLOG_LOGGER_INFO(log_v2::core(),
-                       "Destroying muxer {}: number of events in the queue: {}",
-                       _name, _events_size);
+    absl::MutexLock lock(&_events_m);
+    SPDLOG_LOGGER_INFO(
+        _logger, "Destroying muxer {:p} {}: number of events in the queue: {}",
+        static_cast<void*>(this), _name, _events_size);
     _clean();
   }
-  DEBUG(
-      fmt::format("DESTRUCTOR muxer {:p} {}", static_cast<void*>(this), _name));
+  /* We must unsubscribe once _clean() is over. This is because _clean() is
+   * calling the Broker engine and the engine is unloaded once it has no more
+   * muxer in its array. As the destructor may be called asynchronously, we
+   * must be sure the Broker engine is used while it exists. */
+  unsubscribe();
+
   // caution, unregister_muxer must be the last center method called at muxer
   // destruction to avoid re create a muxer stat entry
   _center->unregister_muxer(_name);
@@ -218,30 +230,27 @@ muxer::~muxer() noexcept {
 void muxer::ack_events(int count) {
   // Remove acknowledged events.
   SPDLOG_LOGGER_TRACE(
-      log_v2::core(),
+      _logger,
       "multiplexing: acknowledging {} events from {} event queue size: {}",
       count, _name, _events_size);
 
   if (count) {
     SPDLOG_LOGGER_DEBUG(
-        log_v2::core(),
-        "multiplexing: acknowledging {} events from {} event queue", count,
-        _name);
-    std::lock_guard<std::mutex> lock(_mutex);
+        _logger, "multiplexing: acknowledging {} events from {} event queue",
+        count, _name);
+    absl::MutexLock lck(&_events_m);
     for (int i = 0; i < count && !_events.empty(); ++i) {
       if (_events.begin() == _pos) {
-        log_v2::core()->error(
-            "multiplexing: attempt to acknowledge "
-            "more events than available in {} event queue: {} size: {}, "
-            "requested, {} "
-            "acknowledged",
+        _logger->error(
+            "multiplexing: attempt to acknowledge more events than available "
+            "in {} event queue: {} size: {}, requested, {} acknowledged",
             _name, _events_size, count, i);
         break;
       }
       _events.pop_front();
       --_events_size;
     }
-    SPDLOG_LOGGER_TRACE(log_v2::core(),
+    SPDLOG_LOGGER_TRACE(_logger,
                         "multiplexing: still {} events in {} event queue",
                         _events_size, _name);
 
@@ -256,8 +265,8 @@ void muxer::ack_events(int count) {
     _update_stats();
   } else {
     SPDLOG_LOGGER_TRACE(
-        log_v2::core(),
-        "multiplexing: acknowledging no events from {} event queue", _name);
+        _logger, "multiplexing: acknowledging no events from {} event queue",
+        _name);
   }
 }
 
@@ -267,12 +276,11 @@ void muxer::ack_events(int count) {
  * @return The number of acknowledged events.
  */
 int32_t muxer::stop() {
-  SPDLOG_LOGGER_INFO(log_v2::core(),
+  SPDLOG_LOGGER_INFO(_logger,
                      "Stopping muxer {}: number of events in the queue: {}",
                      _name, _events_size);
-  std::lock_guard<std::mutex> lck(_mutex);
+  absl::MutexLock lck(&_events_m);
   _update_stats();
-  DEBUG(fmt::format("STOP muxer {:p} {}", static_cast<void*>(this), _name));
   return 0;
 }
 
@@ -297,83 +305,118 @@ uint32_t muxer::event_queue_max_size() noexcept {
   return _event_queue_max_size;
 }
 
+/**
+ * @brief Execute the data_handler() method if it exists and if its execution is
+ * needed, in other words, if there are no data available it is not necessary to
+ * execute the data handler.
+ */
+void muxer::_execute_reader_if_needed() {
+  SPDLOG_LOGGER_DEBUG(
+      _logger, "muxer '{}' execute reader if needed data_handler", _name);
+  bool expected = false;
+  if (_reader_running.compare_exchange_strong(expected, true)) {
+    com::centreon::common::pool::io_context_ptr()->post(
+        [me = shared_from_this(), this] {
+          std::shared_ptr<data_handler> to_call;
+          {
+            absl::MutexLock lck(&_events_m);
+            to_call = _data_handler;
+          }
+          if (to_call) {
+            std::vector<std::shared_ptr<io::data>> to_fill;
+            to_fill.reserve(_events_size);
+            bool still_events_to_read = read(to_fill, _events_size);
+            uint32_t written = to_call->on_events(to_fill);
+            if (written > 0)
+              ack_events(written);
+            if (written != to_fill.size()) {
+              SPDLOG_LOGGER_ERROR(
+                  _logger,
+                  "Unable to handle all the incoming events in muxer '{}'",
+                  _name);
+              clear_action_on_new_data();
+            }
+            _reader_running.store(false);
+          }
+        });
+  }
+}
+
 /**
  *  Add a new event to the internal event list.
  *
  *  @param[in] event Event to add.
  */
 void muxer::publish(const std::deque<std::shared_ptr<io::data>>& event_queue) {
+  _logger->debug("muxer {:p}:publish on muxer '{}': {} events",
+                 static_cast<void*>(this), _name, event_queue.size());
   auto evt = event_queue.begin();
   while (evt != event_queue.end()) {
     bool at_least_one_push_to_queue = false;
-    read_handler async_handler;
     {
-      // we stop this first loop when mux queue is full on order to release
-      // mutex to let read do his job before write to file
-      std::lock_guard<std::mutex> lock(_mutex);
+      // we stop this first loop when mux queue is full in order to release
+      // mutex to let read to do its job before writing to file
+      absl::MutexLock lck(&_events_m);
+      _logger->trace(
+          "muxer::publish ({}) starting the loop to stack events --- "
+          "events_size = {} <> {}",
+          _name, _events_size, event_queue_max_size());
       for (; evt != event_queue.end() && _events_size < event_queue_max_size();
            ++evt) {
         auto event = *evt;
         if (!_write_filter.allows(event->type())) {
-          SPDLOG_LOGGER_TRACE(
-              log_v2::core(),
-              "muxer {} event of type {:x} rejected by write filter", _name,
-              event->type());
+          SPDLOG_LOGGER_TRACE(_logger,
+                              "muxer {} event {} rejected by write filter",
+                              _name, *event);
           continue;
         }
-
         if (event->type() == bbdo::pb_bench::static_type()) {
           add_bench_point(*std::static_pointer_cast<bbdo::pb_bench>(event),
                           _name, "publish");
-          SPDLOG_LOGGER_INFO(log_v2::core(), "{} bench publish {}", _name,
+          SPDLOG_LOGGER_INFO(_logger, "{} bench publish {}", _name,
                              io::data::dump_json{*event});
         }
 
         SPDLOG_LOGGER_TRACE(
-            log_v2::core(),
-            "muxer {} event of type {:x} written queue size: {}", _name,
-            event->type(), _events_size);
+            _logger, "muxer {} event of type {:x} written --- queue size: {}",
+            _name, event->type(), _events_size);
 
         at_least_one_push_to_queue = true;
 
         _push_to_queue(event);
       }
-      if (at_least_one_push_to_queue &&
-          _read_handler) {  // async handler waiting?
-        async_handler = std::move(_read_handler);
-        _read_handler = nullptr;
-      }
-    }
-    if (async_handler) {
-      async_handler();
+      _logger->trace("muxer::publish ({}) loop finished", _name);
+      if (at_least_one_push_to_queue ||
+          _events_size >= event_queue_max_size())  // async handler waiting?
+        _execute_reader_if_needed();
     }
 
     if (evt == event_queue.end()) {
-      std::lock_guard<std::mutex> lock(_mutex);
+      absl::MutexLock lck(&_events_m);
       _update_stats();
       return;
     }
+
     // we have stopped insertion because of full queue => retry
     if (at_least_one_push_to_queue) {
       continue;
     }
-    // nothing pushed => to file
-    std::lock_guard<std::mutex> lock(_mutex);
+    /* The queue is full. The rest is put in the retention file. */
+    absl::MutexLock lck(&_events_m);
     for (; evt != event_queue.end(); ++evt) {
       auto event = *evt;
       if (!_write_filter.allows(event->type())) {
         SPDLOG_LOGGER_TRACE(
-            log_v2::core(),
-            "muxer {} event of type {:x} rejected by write filter", _name,
-            event->type());
+            _logger, "muxer {} event of type {:x} rejected by write filter",
+            _name, event->type());
         continue;
       }
       if (event->type() == bbdo::pb_bench::static_type()) {
         add_bench_point(*std::static_pointer_cast<bbdo::pb_bench>(event), _name,
                         "retention_publish");
-        SPDLOG_LOGGER_INFO(log_v2::core(),
-                           "muxer {} bench publish to file {} {}", _name,
-                           _queue_file_name, io::data::dump_json{*event});
+        SPDLOG_LOGGER_INFO(_logger, "muxer {} bench publish to file {} {}",
+                           _name, _queue_file_name,
+                           io::data::dump_json{*event});
       }
       if (!_file) {
         QueueFileStats* s = _center->muxer_stats(_name)->mutable_queue_file();
@@ -382,19 +425,21 @@ void muxer::publish(const std::deque<std::shared_ptr<io::data>>& event_queue) {
       try {
         _file->write(event);
         SPDLOG_LOGGER_TRACE(
-            log_v2::core(),
+            _logger,
             "{} publish one event of type {:x} to file {} queue size:{}", _name,
             event->type(), _queue_file_name, _events_size);
       } catch (const std::exception& ex) {
         // in case of exception, we lost event. It's mandatory to avoid
         // infinite loop in case of permanent disk problem
-        SPDLOG_LOGGER_ERROR(log_v2::core(), "{} fail to write event to {}: {}",
-                            _name, _queue_file_name, ex.what());
+        SPDLOG_LOGGER_ERROR(_logger, "{} fail to write event to {}: {}", _name,
+                            _queue_file_name, ex.what());
         _file.reset();
       }
     }
     _update_stats();
   }
+  _logger->debug("muxer {:p}:publish on muxer '{}': finished",
+                 static_cast<void*>(this), _name);
 }
 
 /**
@@ -406,21 +451,20 @@ void muxer::publish(const std::deque<std::shared_ptr<io::data>>& event_queue) {
  *  @return Respect io::stream::read()'s return value.
  */
 bool muxer::read(std::shared_ptr<io::data>& event, time_t deadline) {
+  _logger->trace("muxer {:p}:read() call", static_cast<void*>(this));
   bool timed_out{false};
-  std::unique_lock<std::mutex> lock(_mutex);
+  absl::MutexLock lck(&_events_m);
 
   // No data is directly available.
   if (_pos == _events.end()) {
     // Wait a while if subscriber was not shutdown.
     if ((time_t)-1 == deadline)
-      _cv.wait(lock);
-    else if (!deadline) {
+      _no_event_cv.Wait(&_events_m);
+    else if (!deadline)
       timed_out = true;
-    } else {
-      time_t now(time(nullptr));
-      timed_out = _cv.wait_for(lock, std::chrono::seconds(deadline - now)) ==
-                  std::cv_status::timeout;
-    }
+    else
+      _no_event_cv.WaitWithDeadline(&_events_m, absl::FromTimeT(deadline));
+
     if (_pos != _events.end()) {
       event = *_pos;
       ++_pos;
@@ -438,17 +482,17 @@ bool muxer::read(std::shared_ptr<io::data>& event, time_t deadline) {
   _update_stats();
 
   if (event) {
-    SPDLOG_LOGGER_TRACE(log_v2::core(), "{} read {} queue size {}", _name,
-                        *event, _events_size);
+    SPDLOG_LOGGER_TRACE(_logger, "{} read {} queue size {}", _name, *event,
+                        _events_size);
     if (event->type() == bbdo::pb_bench::static_type()) {
       add_bench_point(*std::static_pointer_cast<bbdo::pb_bench>(event), _name,
                       "read");
-      SPDLOG_LOGGER_INFO(log_v2::core(), "{} bench read {}", _name,
+      SPDLOG_LOGGER_INFO(_logger, "{} bench read {}", _name,
                          io::data::dump_json{*event});
     }
   } else {
-    SPDLOG_LOGGER_TRACE(log_v2::core(), "{} queue size {} no event available",
-                        _name, _events_size);
+    SPDLOG_LOGGER_TRACE(_logger, "{} queue size {} no event available", _name,
+                        _events_size);
   }
   return !timed_out;
 }
@@ -477,7 +521,7 @@ const std::string& muxer::write_filters_as_str() const {
  *  @return  The size of the event queue.
  */
 uint32_t muxer::get_event_queue_size() const {
-  std::lock_guard<std::mutex> lock(_mutex);
+  absl::MutexLock lck(&_events_m);
   return _events_size;
 }
 
@@ -485,11 +529,11 @@ uint32_t muxer::get_event_queue_size() const {
  *  Reprocess non-acknowledged events.
  */
 void muxer::nack_events() {
-  SPDLOG_LOGGER_DEBUG(log_v2::core(),
+  SPDLOG_LOGGER_DEBUG(_logger,
                       "multiplexing: reprocessing unacknowledged events from "
                       "{} event queue with {} waiting events",
                       _name, _events_size);
-  std::lock_guard<std::mutex> lock(_mutex);
+  absl::MutexLock lck(&_events_m);
   _pos = _events.begin();
   _update_stats();
 }
@@ -501,7 +545,7 @@ void muxer::nack_events() {
  */
 void muxer::statistics(nlohmann::json& tree) const {
   // Lock object.
-  std::lock_guard<std::mutex> lock(_mutex);
+  absl::MutexLock lck(&_events_m);
 
   // Queue file mode.
   bool queue_file_enabled(_file.get());
@@ -523,8 +567,7 @@ void muxer::statistics(nlohmann::json& tree) const {
  *  Wake all threads waiting on this subscriber.
  */
 void muxer::wake() {
-  std::lock_guard<std::mutex> lock(_mutex);
-  _cv.notify_all();
+  _no_event_cv.SignalAll();
 }
 
 /**
@@ -533,6 +576,7 @@ void muxer::wake() {
  *  @param[in] d  Event to multiplex.
  */
 int muxer::write(std::shared_ptr<io::data> const& d) {
+  _logger->debug("write on muxer '{}'", _name);
   if (!d) {
     return 1;
   }
@@ -540,12 +584,12 @@ int muxer::write(std::shared_ptr<io::data> const& d) {
     if (d->type() == bbdo::pb_bench::static_type()) {
       add_bench_point(*std::static_pointer_cast<bbdo::pb_bench>(d), _name,
                       "write");
-      SPDLOG_LOGGER_INFO(log_v2::core(), "{} bench write {}", _name,
+      SPDLOG_LOGGER_INFO(_logger, "{} bench write {}", _name,
                          io::data::dump_json{*d});
     }
     _engine->publish(d);
   } else {
-    SPDLOG_LOGGER_TRACE(log_v2::core(),
+    SPDLOG_LOGGER_TRACE(_logger,
                         "muxer {} event of type {:x} rejected by read filter",
                         _name, d->type());
   }
@@ -558,6 +602,8 @@ int muxer::write(std::shared_ptr<io::data> const& d) {
  * @param to_publish list of event where not allowed event will be erased
  */
 void muxer::write(std::deque<std::shared_ptr<io::data>>& to_publish) {
+  _logger->debug("write on muxer '{}' {} events (bulk)", _name,
+                 to_publish.size());
   for (auto list_iter = to_publish.begin();
        !to_publish.empty() && list_iter != to_publish.end();) {
     const std::shared_ptr<io::data>& d = *list_iter;
@@ -565,7 +611,7 @@ void muxer::write(std::deque<std::shared_ptr<io::data>>& to_publish) {
       if (d->type() == bbdo::pb_bench::static_type()) {
         add_bench_point(*std::static_pointer_cast<bbdo::pb_bench>(d), _name,
                         "write");
-        SPDLOG_LOGGER_INFO(log_v2::core(), "{} bench write {}", _name,
+        SPDLOG_LOGGER_INFO(_logger, "{} bench write {}", _name,
                            io::data::dump_json{*d});
       }
       ++list_iter;
@@ -580,17 +626,14 @@ void muxer::write(std::deque<std::shared_ptr<io::data>>& to_publish) {
 
 /**
  *  Release all events stored within the internal list.
- *  Warning: _mutex must be locked to call this function.
+ *  Warning: _events_m must be locked to call this function.
  */
 void muxer::_clean() {
   _file.reset();
   _center->clear_muxer_queue_file(_name);
-  //  _center->execute([name=this->_name] {
-  //      _center->muxer_stats(name)->mutable_queue_file()->Clear();
-  //  });
   if (_persistent && !_events.empty()) {
     try {
-      SPDLOG_LOGGER_TRACE(log_v2::core(), "muxer: sending {} events to {}",
+      SPDLOG_LOGGER_TRACE(_logger, "muxer: sending {} events to {}",
                           _events_size, memory_file(_name));
       auto mf{std::make_unique<persistent_file>(memory_file(_name), nullptr)};
       while (!_events.empty()) {
@@ -599,9 +642,8 @@ void muxer::_clean() {
         --_events_size;
       }
     } catch (std::exception const& e) {
-      log_v2::core()->error(
-          "multiplexing: could not backup memory queue of '{}': {}", _name,
-          e.what());
+      _logger->error("multiplexing: could not backup memory queue of '{}': {}",
+                     _name, e.what());
     }
   }
   _events.clear();
@@ -612,7 +654,7 @@ void muxer::_clean() {
 
 /**
  *  Get event from retention file.
- *  Warning: lock _mutex before using this function.
+ *  Warning: lock _events_m before using this function.
  *
  *  @param[out] event  Last event available. Null if none is available.
  */
@@ -660,33 +702,33 @@ std::string muxer::queue_file(std::string const& name) {
 }
 
 /**
- *  Push event to queue (_mutex is locked when this method is called).
+ *  Push event to queue (_events_m is locked when this method is called).
  *
  *  @param[in] event  New event.
  */
 void muxer::_push_to_queue(std::shared_ptr<io::data> const& event) {
   bool pos_has_no_more_to_read(_pos == _events.end());
-  SPDLOG_LOGGER_TRACE(log_v2::core(), "muxer {} event of type {:x} pushed",
-                      _name, event->type());
+  SPDLOG_LOGGER_TRACE(_logger, "muxer {} event of type {:x} pushed", _name,
+                      event->type());
   _events.push_back(event);
   ++_events_size;
 
   if (pos_has_no_more_to_read) {
     _pos = --_events.end();
-    _cv.notify_one();
+    _no_event_cv.Signal();
   }
 }
 
 /**
  * @brief Fill statistics if it happened more than 1 second ago
  *
- * Warning: _mutex must be locked before while calling this function.
+ * Warning: _events_m must be locked before while calling this function.
  */
 void muxer::_update_stats() noexcept {
   std::time_t now{std::time(nullptr)};
   if (now - _last_stats > 0) {
     _last_stats = now;
-    /* Since _mutex is locked, we can get interesting values and copy them
+    /* Since _events_m is locked, we can get interesting values and copy them
      * in the capture. Then the execute() function can put them in the stats
      * object asynchronously. */
     _center->update_muxer(_name, _file ? _queue_file_name : "", _events_size,
@@ -698,8 +740,7 @@ void muxer::_update_stats() noexcept {
  *  Remove all the queue files attached to this muxer.
  */
 void muxer::remove_queue_files() {
-  SPDLOG_LOGGER_INFO(log_v2::core(), "multiplexing: '{}' removed",
-                     _queue_file_name);
+  SPDLOG_LOGGER_INFO(_logger, "multiplexing: '{}' removed", _queue_file_name);
 
   /* Here _file is already destroyed */
   QueueFileStats* stats = _center->muxer_stats(_name)->mutable_queue_file();
@@ -723,7 +764,7 @@ const std::string& muxer::name() const {
  * @param r_filter        The read filter.
  */
 void muxer::set_read_filter(const muxer_filter& r_filter) {
-  log_v2::config()->trace("multiplexing: '{}' set read filter...", _name);
+  _logger->trace("multiplexing: '{}' set read filter...", _name);
   _read_filter = r_filter;
   _read_filters_str = misc::dump_filters(r_filter);
 }
@@ -735,23 +776,26 @@ void muxer::set_read_filter(const muxer_filter& r_filter) {
  * @param r_filter        The write filter.
  */
 void muxer::set_write_filter(const muxer_filter& w_filter) {
-  log_v2::config()->trace("multiplexing: '{}' set write filter...", _name);
+  _logger->trace("multiplexing: '{}' set write filter...", _name);
   _write_filter = w_filter;
   _write_filters_str = misc::dump_filters(w_filter);
 }
 
-/**
- * @brief clear readhandler in case of caller owning this object has terminate
- *
- */
-void muxer::clear_read_handler() {
-  std::unique_lock<std::mutex> lock(_mutex);
-  _read_handler = nullptr;
-}
-
 /**
  * @brief Unsubscribe this muxer from the parent engine.
  */
 void muxer::unsubscribe() {
+  _logger->debug("multiplexing: unsubscribe '{}'", _name);
   _engine->unsubscribe_muxer(this);
 }
+
+void muxer::set_action_on_new_data(
+    const std::shared_ptr<data_handler>& handler) {
+  absl::MutexLock lck(&_events_m);
+  _data_handler = handler;
+}
+
+void muxer::clear_action_on_new_data() {
+  absl::MutexLock lck(&_events_m);
+  _data_handler.reset();
+}
