@@ -1,5 +1,5 @@
-/*
- * Copyright 2018-2024 Centreon
+/**
+ * Copyright 2018-2023 Centreon
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,19 +15,19 @@
  *
  * For more information : contact@centreon.com
  */
-
 #include <errmsg.h>
 #include <mysqld_error.h>
 
 #include "com/centreon/broker/config/applier/init.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/misc/misc.hh"
 #include "com/centreon/broker/sql/mysql_manager.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::exceptions;
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::database;
+using log_v2 = com::centreon::common::log_v2::log_v2;
 
 constexpr const char* mysql_error::msg[];
 
@@ -178,13 +178,12 @@ bool mysql_connection::_try_to_reconnect() {
 
   _clear_connection();
   SPDLOG_LOGGER_INFO(
-      log_v2::sql(),
+      _logger,
       "mysql_connection {:p}: server has gone away, attempt to reconnect",
       static_cast<const void*>(this));
   _conn = mysql_init(nullptr);
   if (!_conn) {
-    SPDLOG_LOGGER_ERROR(log_v2::sql(),
-                        "mysql_connection: reconnection failed.");
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: reconnection failed.");
     set_error_message("mysql_connection: reconnection failed.");
     return false;
   }
@@ -200,7 +199,7 @@ bool mysql_connection::_try_to_reconnect() {
                           (_socket == "" ? nullptr : _socket.c_str()),
                           CLIENT_FOUND_ROWS)) {
     SPDLOG_LOGGER_ERROR(
-        log_v2::sql(),
+        _logger,
         "mysql_connection: The mysql/mariadb database seems not started.");
     set_error_message(
         "mysql_connection: The mysql/mariadb database seems not started.");
@@ -217,19 +216,18 @@ bool mysql_connection::_try_to_reconnect() {
     MYSQL_STMT* s = mysql_stmt_init(_conn);
     if (!s) {
       SPDLOG_LOGGER_ERROR(
-          log_v2::sql(),
-          "mysql_connection: impossible to reset prepared statements");
+          _logger, "mysql_connection: impossible to reset prepared statements");
       fail = true;
       break;
     } else {
       if (mysql_stmt_prepare(s, itq->second.c_str(), itq->second.size())) {
-        SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}",
+        SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}",
                             mysql_stmt_error(s));
         fail = true;
         break;
       } else {
         _stmt[itq->first] = s;
-        SPDLOG_LOGGER_TRACE(log_v2::sql(),
+        SPDLOG_LOGGER_TRACE(_logger,
                             "mysql_connection {:p}: statement prepared {} "
                             "mysql_statement_id={}: {}",
                             static_cast<const void*>(this), itq->first,
@@ -238,7 +236,7 @@ bool mysql_connection::_try_to_reconnect() {
     }
   }
   if (!fail) {
-    SPDLOG_LOGGER_DEBUG(log_v2::sql(), "mysql_connection {:p}: connected",
+    SPDLOG_LOGGER_DEBUG(_logger, "mysql_connection {:p}: connected",
                         static_cast<const void*>(this));
     _switch_point = std::time(nullptr);
     _connected = true;
@@ -251,7 +249,7 @@ bool mysql_connection::_try_to_reconnect() {
                           static_cast<const void*>(this), ::mysql_error(_conn))
             : fmt::format("connection {:p} fail to connect",
                           static_cast<const void*>(this));
-    SPDLOG_LOGGER_ERROR(log_v2::sql(), err_msg);
+    SPDLOG_LOGGER_ERROR(_logger, err_msg);
     set_error_message(err_msg);
     return false;
   }
@@ -262,20 +260,20 @@ void mysql_connection::_query(mysql_task* t) {
 
   sql::stats::query_span stats(&_stats, task->query);
 
-  SPDLOG_LOGGER_DEBUG(log_v2::sql(), "mysql_connection {:p}: run query: {}",
+  SPDLOG_LOGGER_DEBUG(_logger, "mysql_connection {:p}: run query: {}",
                       static_cast<const void*>(this), task->query);
   if (mysql_query(_conn, task->query.c_str())) {
     const char* m = mysql_error::msg[task->error_code];
     std::string err_msg(fmt::format("{} errrno={} {}", m, ::mysql_errno(_conn),
                                     ::mysql_error(_conn)));
-    SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
     if (_server_error(::mysql_errno(_conn)))
       set_error_message(err_msg);
   } else {
     _last_access = time(nullptr);
     set_need_to_commit();
   }
-  SPDLOG_LOGGER_TRACE(log_v2::sql(), "mysql_connection {:p}: end run query: {}",
+  SPDLOG_LOGGER_TRACE(_logger, "mysql_connection {:p}: end run query: {}",
                       static_cast<const void*>(this), task->query);
 }
 
@@ -284,11 +282,11 @@ void mysql_connection::_query_res(mysql_task* t) {
 
   sql::stats::query_span stats(&_stats, task->query);
 
-  SPDLOG_LOGGER_DEBUG(log_v2::sql(), "mysql_connection {:p}: run query: {}",
+  SPDLOG_LOGGER_DEBUG(_logger, "mysql_connection {:p}: run query: {}",
                       static_cast<const void*>(this), task->query);
   if (mysql_query(_conn, task->query.c_str())) {
     std::string err_msg(::mysql_error(_conn));
-    SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
 
     if (_server_error(mysql_errno(_conn)))
       /* In case of server error, no exception because we will try again very
@@ -311,11 +309,11 @@ void mysql_connection::_query_res(mysql_task* t) {
 void mysql_connection::_query_int(mysql_task* t) {
   mysql_task_run_int* task = static_cast<mysql_task_run_int*>(t);
   sql::stats::query_span stats(&_stats, task->query);
-  SPDLOG_LOGGER_DEBUG(log_v2::sql(), "mysql_connection {:p}: run query: {}",
+  SPDLOG_LOGGER_DEBUG(_logger, "mysql_connection {:p}: run query: {}",
                       static_cast<const void*>(this), task->query);
   if (mysql_query(_conn, task->query.c_str())) {
     std::string err_msg(::mysql_error(_conn));
-    SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
 
     if (_server_error(::mysql_errno(_conn)))
       /* In case of server error, no exception because we will try again very
@@ -345,7 +343,7 @@ void mysql_connection::_commit(mysql_task* t) {
     int32_t attempts = 0;
     int res;
     if (_need_commit) {
-      SPDLOG_LOGGER_DEBUG(log_v2::sql(), "mysql_connection {:p} : commit",
+      SPDLOG_LOGGER_DEBUG(_logger, "mysql_connection {:p} : commit",
                           static_cast<const void*>(this));
       while (attempts++ < MAX_ATTEMPTS && (res = mysql_commit(_conn))) {
         err_msg = ::mysql_error(_conn);
@@ -353,28 +351,27 @@ void mysql_connection::_commit(mysql_task* t) {
           set_error_message(err_msg);
           break;
         }
-        SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+        SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
         std::this_thread::sleep_for(std::chrono::milliseconds(50));
       }
       if (res == 0)
         _last_access = std::time(nullptr);
     } else {
-      SPDLOG_LOGGER_TRACE(log_v2::sql(),
-                          "mysql_connection {:p} : nothing to commit",
+      SPDLOG_LOGGER_TRACE(_logger, "mysql_connection {:p} : nothing to commit",
                           static_cast<const void*>(this));
       res = 0;
     }
 
     if (res) {
       err_msg = fmt::format("Error during commit: {}", ::mysql_error(_conn));
-      SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+      SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
     } else {
       /* No more queries are waiting for a commit now. */
       _need_commit = false;
       _last_commit = time(nullptr);
     }
   } else {
-    SPDLOG_LOGGER_TRACE(log_v2::sql(), "mysql_connection {:p} : auto commit",
+    SPDLOG_LOGGER_TRACE(_logger, "mysql_connection {:p} : auto commit",
                         static_cast<const void*>(this));
   }
 
@@ -396,14 +393,14 @@ void mysql_connection::_commit(mysql_task* t) {
 void mysql_connection::_prepare(mysql_task* t) {
   mysql_task_prepare* task(static_cast<mysql_task_prepare*>(t));
   if (_stmt.find(task->id) != _stmt.end()) {
-    SPDLOG_LOGGER_ERROR(log_v2::sql(),
+    SPDLOG_LOGGER_ERROR(_logger,
                         "mysql_connection: Statement already prepared: {} ({})",
                         task->id, task->query);
     return;
   }
 
   _stmt_query[task->id] = task->query;
-  SPDLOG_LOGGER_DEBUG(log_v2::sql(),
+  SPDLOG_LOGGER_DEBUG(_logger,
                       "mysql_connection {:p}: prepare statement {}: {}",
                       static_cast<const void*>(this), task->id, task->query);
   MYSQL_STMT* stmt(mysql_stmt_init(_conn));
@@ -412,12 +409,12 @@ void mysql_connection::_prepare(mysql_task* t) {
   else {
     if (mysql_stmt_prepare(stmt, task->query.c_str(), task->query.size())) {
       std::string err_msg(::mysql_stmt_error(stmt));
-      SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+      SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
       set_error_message(err_msg);
     } else {
       _last_access = time(nullptr);
       _stmt[task->id] = stmt;
-      SPDLOG_LOGGER_TRACE(log_v2::sql(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "mysql_connection {:p}: statement prepared {} "
                           "mysql_statement_id={}: {}",
                           static_cast<const void*>(this), task->id,
@@ -435,8 +432,7 @@ void mysql_connection::_statement(mysql_task* t) {
   sql::stats::stmt_span stats(&_stats, task->statement_id, query);
   MYSQL_STMT* stmt(_stmt[task->statement_id]);
   if (!stmt) {
-    SPDLOG_LOGGER_ERROR(log_v2::sql(),
-                        "mysql_connection: no statement to execute");
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: no statement to execute");
     set_error_message("statement {} not prepared", task->statement_id);
     return;
   }
@@ -452,7 +448,7 @@ void mysql_connection::_statement(mysql_task* t) {
   }
   if (bb && mysql_stmt_bind_param(stmt, bb)) {
     SPDLOG_LOGGER_ERROR(
-        log_v2::sql(),
+        _logger,
         "mysql_connection: Error while binding values in statement: {}",
         ::mysql_stmt_error(stmt));
   } else {
@@ -461,8 +457,8 @@ void mysql_connection::_statement(mysql_task* t) {
         std::chrono::system_clock::now();
     for (;;) {
       SPDLOG_LOGGER_TRACE(
-          log_v2::sql(),
-          "mysql_connection {:p}: execute statement {} attempt {}: {}",
+          _logger,
+          "mysql_connection {:p}: execute statement {:x} attempt {}: {}",
           static_cast<const void*>(this), task->statement_id, attempts, query);
       if (mysql_stmt_execute(stmt)) {
         int32_t err_code = ::mysql_stmt_errno(stmt);
@@ -470,14 +466,14 @@ void mysql_connection::_statement(mysql_task* t) {
                                         mysql_error::msg[task->error_code],
                                         err_code, ::mysql_stmt_error(stmt)));
         if (err_code == 0) {
-          SPDLOG_LOGGER_ERROR(log_v2::sql(),
+          SPDLOG_LOGGER_TRACE(_logger,
                               "mysql_connection: errno=0, so we simulate a "
                               "server error CR_SERVER_LOST");
           err_code = CR_SERVER_LOST;
         } else {
-          SPDLOG_LOGGER_ERROR(log_v2::sql(),
-                              "connection fail to execute statement {:p}: {}",
-                              static_cast<const void*>(this), err_msg);
+            SPDLOG_LOGGER_ERROR(_logger,
+                      "connection fail to execute statement {:p}: {}",
+                      static_cast<const void*>(this), err_msg);
         }
         if (_server_error(err_code)) {
           set_error_message(err_msg);
@@ -489,15 +485,14 @@ void mysql_connection::_statement(mysql_task* t) {
 
         if (mysql_commit(_conn)) {
           SPDLOG_LOGGER_ERROR(
-              log_v2::sql(),
+              _logger,
               "connection fail commit after execute statement failure {:p}",
               static_cast<const void*>(this));
           set_error_message("Commit failed after execute statement");
           break;
         }
 
-        SPDLOG_LOGGER_ERROR(log_v2::sql(),
-                            "mysql_connection {:p} attempts {}: {}",
+        SPDLOG_LOGGER_ERROR(_logger, "mysql_connection {:p} attempts {}: {}",
                             static_cast<const void*>(this), attempts, err_msg);
         if (++attempts >= MAX_ATTEMPTS) {
           if (_server_error(::mysql_stmt_errno(stmt)))
@@ -506,9 +501,9 @@ void mysql_connection::_statement(mysql_task* t) {
           break;
         }
       } else {
-        SPDLOG_LOGGER_TRACE(log_v2::sql(),
+        SPDLOG_LOGGER_TRACE(_logger,
                             "mysql_connection {:p}: success execute statement "
-                            "{} attempt {}",
+                            "{:x} attempt {}",
                             static_cast<const void*>(this), task->statement_id,
                             _stmt_query[task->statement_id]);
         _last_access = time(nullptr);
@@ -517,9 +512,9 @@ void mysql_connection::_statement(mysql_task* t) {
       }
       std::this_thread::sleep_for(std::chrono::milliseconds(50));
     }
-    SPDLOG_LOGGER_TRACE(log_v2::sql(),
+    SPDLOG_LOGGER_TRACE(_logger,
                         "mysql_connection {:p}: end execute statement "
-                        "{} attempt {} duration {}s: {}",
+                        "{:x} attempt {} duration {}s: {}",
                         static_cast<const void*>(this), task->statement_id,
                         attempts,
                         std::chrono::duration_cast<std::chrono::seconds>(
@@ -533,13 +528,11 @@ void mysql_connection::_statement_res(mysql_task* t) {
   mysql_task_statement_res* task(static_cast<mysql_task_statement_res*>(t));
   const std::string& query = _stmt_query[task->statement_id];
   sql::stats::stmt_span stats(&_stats, task->statement_id, query);
-  SPDLOG_LOGGER_DEBUG(log_v2::sql(),
-                      "mysql_connection: execute statement {}: {}",
+  SPDLOG_LOGGER_DEBUG(_logger, "mysql_connection: execute statement {:x}: {}",
                       task->statement_id, query);
   MYSQL_STMT* stmt(_stmt[task->statement_id]);
   if (!stmt) {
-    SPDLOG_LOGGER_ERROR(log_v2::sql(),
-                        "mysql_connection: no statement to execute");
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: no statement to execute");
     msg_fmt e("statement not prepared");
     task->promise.set_exception(std::make_exception_ptr<msg_fmt>(e));
     return;
@@ -556,7 +549,7 @@ void mysql_connection::_statement_res(mysql_task* t) {
   }
   if (bb && mysql_stmt_bind_param(stmt, bb)) {
     std::string err_msg(::mysql_stmt_error(stmt));
-    SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
     msg_fmt e("statement and get result failed: {}", err_msg);
     task->promise.set_exception(std::make_exception_ptr<msg_fmt>(e));
   } else {
@@ -564,7 +557,7 @@ void mysql_connection::_statement_res(mysql_task* t) {
     for (;;) {
       if (mysql_stmt_execute(stmt)) {
         std::string err_msg(::mysql_stmt_error(stmt));
-        SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+        SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
         if (_server_error(mysql_stmt_errno(stmt))) {
           /* In case of server error, no exception because we will try again
            * very soon */
@@ -581,7 +574,7 @@ void mysql_connection::_statement_res(mysql_task* t) {
 
         if (mysql_commit(_conn)) {
           SPDLOG_LOGGER_ERROR(
-              log_v2::sql(),
+              _logger,
               "connection fail commit after execute statement failure {:p}",
               static_cast<const void*>(this));
           if (_server_error(mysql_errno(_conn))) {
@@ -616,7 +609,8 @@ void mysql_connection::_statement_res(mysql_task* t) {
             task->promise.set_value(nullptr);
         } else {
           int size(mysql_num_fields(prepare_meta_result));
-          auto bind = std::make_unique<mysql_bind_result>(size, task->length);
+          auto bind =
+              std::make_unique<mysql_bind_result>(size, task->length, _logger);
 
           if (mysql_stmt_bind_result(stmt, bind->get_bind())) {
             std::string err_msg(::mysql_stmt_error(stmt));
@@ -655,13 +649,11 @@ void mysql_connection::_statement_int(mysql_task* t) {
       static_cast<mysql_task_statement_int<T>*>(t));
   const std::string& query = _stmt_query[task->statement_id];
   sql::stats::stmt_span stats(&_stats, task->statement_id, query);
-  SPDLOG_LOGGER_DEBUG(log_v2::sql(),
-                      "mysql_connection: execute statement {}: {}",
+  SPDLOG_LOGGER_DEBUG(_logger, "mysql_connection: execute statement {:x}: {}",
                       task->statement_id, query);
   MYSQL_STMT* stmt(_stmt[task->statement_id]);
   if (!stmt) {
-    SPDLOG_LOGGER_ERROR(log_v2::sql(),
-                        "mysql_connection: no statement to execute");
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: no statement to execute");
     msg_fmt e("statement not prepared");
     task->promise.set_exception(std::make_exception_ptr<msg_fmt>(e));
     return;
@@ -678,7 +670,7 @@ void mysql_connection::_statement_int(mysql_task* t) {
   }
   if (bb && mysql_stmt_bind_param(stmt, bb)) {
     std::string err_msg(::mysql_stmt_error(stmt));
-    SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+    SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
     msg_fmt e(err_msg);
     task->promise.set_exception(std::make_exception_ptr<msg_fmt>(e));
   } else {
@@ -686,7 +678,7 @@ void mysql_connection::_statement_int(mysql_task* t) {
     for (;;) {
       if (mysql_stmt_execute(stmt)) {
         std::string err_msg(::mysql_stmt_error(stmt));
-        SPDLOG_LOGGER_ERROR(log_v2::sql(), "mysql_connection: {}", err_msg);
+        SPDLOG_LOGGER_ERROR(_logger, "mysql_connection: {}", err_msg);
         if (_server_error(mysql_stmt_errno(stmt))) {
           /* In case of server error, no exception because we will try again
            * very soon */
@@ -703,7 +695,7 @@ void mysql_connection::_statement_int(mysql_task* t) {
 
         if (mysql_commit(_conn)) {
           SPDLOG_LOGGER_ERROR(
-              log_v2::sql(),
+              _logger,
               "connection fail commit after execute statement failure {:p}",
               static_cast<const void*>(this));
           if (_server_error(mysql_errno(_conn))) {
@@ -748,7 +740,7 @@ void mysql_connection::_fetch_row_sync(mysql_task* t) {
     int res(mysql_stmt_fetch(stmt));
     if (res != 0) {
       if (res == MYSQL_DATA_TRUNCATED)
-        log_v2::sql()->error(
+        _logger->error(
             "columns in the current row are too long, data would be truncated");
       task->result->get_bind()->set_empty();
     }
@@ -871,7 +863,7 @@ void mysql_connection::_run() {
   }
 
   if (config::applier::mode == config::applier::finished) {
-    SPDLOG_LOGGER_DEBUG(log_v2::sql(), "Connection over.");
+    SPDLOG_LOGGER_DEBUG(_logger, "Connection over.");
     _state = finished;
     _start_condition.notify_all();
     lck.unlock();
@@ -904,7 +896,7 @@ void mysql_connection::_run() {
       if (_error.is_active()) {
         if (!_try_to_reconnect()) {
           if (!reconnect_failed_logged) {
-            SPDLOG_LOGGER_ERROR(log_v2::sql(), "SQL: Reconnection failed.");
+            SPDLOG_LOGGER_ERROR(_logger, "SQL: Reconnection failed.");
             reconnect_failed_logged = true;
           } else if (config::applier::mode == config::applier::finished) {
             _finish();
@@ -930,7 +922,7 @@ void mysql_connection::_run() {
   _state = finished;
   _start_condition.notify_all();
   mysql_thread_end();
-  log_v2::core()->trace("mysql connection main loop finished.");
+  _logger->trace("mysql connection main loop finished.");
 }
 
 /**
@@ -1001,7 +993,7 @@ void mysql_connection::_process_tasks(
         _commit(nullptr);
       }
     } else {
-      SPDLOG_LOGGER_ERROR(log_v2::sql(),
+      SPDLOG_LOGGER_ERROR(_logger,
                           "mysql_connection {:p}: Error type not managed...",
                           static_cast<const void*>(this));
     }
@@ -1029,23 +1021,23 @@ void mysql_connection::_process_while_empty_task(
   auto ping = [&]() {
     std::time_t now = std::time(nullptr);
     if (now >= _last_access + 30) {
-      SPDLOG_LOGGER_TRACE(log_v2::sql(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "mysql_connection {:p} SQL: performing mysql_ping.",
                           static_cast<const void*>(this));
       if (mysql_ping(_conn)) {
         if (!_try_to_reconnect()) {
-          SPDLOG_LOGGER_ERROR(log_v2::sql(),
+          SPDLOG_LOGGER_ERROR(_logger,
                               "mysql_connection {:p} SQL: Reconnection failed.",
                               static_cast<const void*>(this));
         }
       } else {
         SPDLOG_LOGGER_TRACE(
-            log_v2::sql(), "mysql_connection {:p} SQL: connection always alive",
+            _logger, "mysql_connection {:p} SQL: connection always alive",
             static_cast<const void*>(this));
         _last_access = now;
       }
     } else {
-      SPDLOG_LOGGER_TRACE(log_v2::sql(),
+      SPDLOG_LOGGER_TRACE(_logger,
                           "mysql_connection {:p} SQL: last access to the "
                           "database for this connection for {}s",
                           static_cast<const void*>(this), now - _last_access);
@@ -1060,8 +1052,7 @@ void mysql_connection::_process_while_empty_task(
     if (time(nullptr) > _last_commit + _max_second_commit_delay) {
       _commit(nullptr);
     }
-    SPDLOG_LOGGER_TRACE(log_v2::sql(), "_tasks_list.size()={}",
-                        _tasks_list.size());
+    SPDLOG_LOGGER_TRACE(_logger, "_tasks_list.size()={}", _tasks_list.size());
 
     lock.unlock();
     ping();
@@ -1075,7 +1066,7 @@ void mysql_connection::_process_while_empty_task(
   } else {
     tasks_list.swap(_tasks_list);
     lock.unlock();
-    SPDLOG_LOGGER_TRACE(log_v2::sql(), "tasks_list={}", _get_stack(tasks_list));
+    SPDLOG_LOGGER_TRACE(_logger, "tasks_list={}", _get_stack(tasks_list));
     ping();
   }
 }
@@ -1084,8 +1075,11 @@ void mysql_connection::_process_while_empty_task(
 /*                    Methods executed by the main thread                     */
 /******************************************************************************/
 
-mysql_connection::mysql_connection(const database_config& db_cfg,
-                                   SqlConnectionStats* stats)
+mysql_connection::mysql_connection(
+    const database_config& db_cfg,
+    SqlConnectionStats* stats,
+    const std::shared_ptr<spdlog::logger>& logger,
+    std::shared_ptr<stats::center> center)
     : _conn(nullptr),
       _finish_asked(false),
       _tasks_count{0},
@@ -1109,11 +1103,10 @@ mysql_connection::mysql_connection(const database_config& db_cfg,
       _last_stats{std::time(nullptr)},
       _qps(db_cfg.get_queries_per_transaction()),
       _category(db_cfg.get_category()),
-      _center{stats::center::instance_ptr()} {
-  DEBUG(fmt::format("CONSTRUCTOR mysql_connection {:p}",
-                    static_cast<void*>(this)));
+      _logger{logger},
+      _center{std::move(center)} {
   std::unique_lock<std::mutex> lck(_start_m);
-  SPDLOG_LOGGER_INFO(log_v2::sql(),
+  SPDLOG_LOGGER_INFO(_logger,
                      "mysql_connection: starting connection {:p} to {}",
                      static_cast<const void*>(this), db_cfg);
   _thread = std::make_unique<std::thread>(&mysql_connection::_run, this);
@@ -1121,13 +1114,12 @@ mysql_connection::mysql_connection(const database_config& db_cfg,
   if (_state == finished) {
     _thread->join();
     SPDLOG_LOGGER_ERROR(
-        log_v2::sql(),
-        "mysql_connection {:p}: error while starting connection: {}",
+        _logger, "mysql_connection {:p}: error while starting connection: {}",
         static_cast<const void*>(this), _error.get_message());
     throw msg_fmt("mysql_connection: error while starting connection");
   }
   pthread_setname_np(_thread->native_handle(), "mysql_connect");
-  SPDLOG_LOGGER_INFO(log_v2::sql(), "mysql_connection: connection started");
+  SPDLOG_LOGGER_INFO(_logger, "mysql_connection: connection started");
   _center->update(&SqlConnectionStats::set_waiting_tasks, _proto_stats, 0);
 }
 
@@ -1136,13 +1128,11 @@ mysql_connection::mysql_connection(const database_config& db_cfg,
  * the end will occur only when all the queries will be played.
  */
 mysql_connection::~mysql_connection() {
-  SPDLOG_LOGGER_INFO(log_v2::sql(), "mysql_connection {:p}: finished",
+  SPDLOG_LOGGER_INFO(_logger, "mysql_connection {:p}: finished",
                      static_cast<const void*>(this));
   stop();
   _center->remove_connection(_proto_stats);
   _thread->join();
-  DEBUG(fmt::format("DESTRUCTOR mysql_connection {:p}",
-                    static_cast<void*>(this)));
 }
 
 void mysql_connection::_push(std::unique_ptr<mysql_task>&& q) {
