@@ -18,29 +18,32 @@
 #include "com/centreon/broker/unified_sql/stream.hh"
 
 #include <absl/strings/str_split.h>
+#include <absl/synchronization/mutex.h>
 #include <cassert>
 #include <cstring>
 #include <thread>
 
+#include "bbdo/events.hh"
 #include "bbdo/remove_graph_message.pb.h"
 #include "bbdo/storage/index_mapping.hh"
 #include "com/centreon/broker/cache/global_cache.hh"
 #include "com/centreon/broker/config/applier/state.hh"
 #include "com/centreon/broker/exceptions/shutdown.hh"
-#include "com/centreon/broker/log_v2.hh"
-#include "com/centreon/broker/misc/perfdata.hh"
 #include "com/centreon/broker/multiplexing/publisher.hh"
 #include "com/centreon/broker/neb/events.hh"
 #include "com/centreon/broker/sql/mysql_bulk_stmt.hh"
 #include "com/centreon/broker/sql/mysql_result.hh"
 #include "com/centreon/broker/stats/center.hh"
 #include "com/centreon/broker/unified_sql/internal.hh"
+#include "com/centreon/common/perfdata.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::exceptions;
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::database;
 using namespace com::centreon::broker::unified_sql;
+using log_v2 = com::centreon::common::log_v2::log_v2;
 
 const std::string stream::_index_data_insert_request(
     "INSERT INTO index_data "
@@ -86,7 +89,7 @@ constexpr void (stream::*const stream::neb_processing_table[])(
     &stream::_process_service_group_member,
     &stream::_process_service,
     &stream::_process_service_status,
-    &stream::_process_instance_configuration,
+    nullptr,
     &stream::_process_responsive_instance,
     &stream::_process_pb_service,
     &stream::_process_pb_adaptive_service,
@@ -108,6 +111,16 @@ constexpr void (stream::*const stream::neb_processing_table[])(
     &stream::_process_pb_instance,
     &stream::_process_pb_acknowledgement,
     &stream::_process_pb_responsive_instance,
+    &stream::_process_pb_host_dependency,
+    &stream::_process_pb_service_dependency,
+    &stream::_process_pb_host_group,
+    &stream::_process_pb_host_group_member,
+    &stream::_process_pb_service_group,
+    &stream::_process_pb_service_group_member,
+    &stream::_process_pb_host_parent,
+    nullptr,  // pb_instance_configuration
+    &stream::_process_pb_adaptive_service_status,
+    &stream::_process_pb_adaptive_host_status,
 };
 
 constexpr size_t neb_processing_table_size =
@@ -158,13 +171,15 @@ stream::stream(const database_config& dbcfg,
       _max_log_queries{_max_pending_queries},
       _next_update_metrics{std::time_t(nullptr) + 10},
       _next_loop_timeout{std::time_t(nullptr) + _loop_timeout},
-      _queues_timer{pool::io_context()},
+      _queues_timer{com::centreon::common::pool::io_context()},
       _stop_check_queues{false},
       _check_queues_stopped{false},
       _center{stats::center::instance_ptr()},
       _stats{_center->register_conflict_manager()},
-      _group_clean_timer{pool::io_context()},
-      _loop_timer{pool::io_context()},
+      _group_clean_timer{com::centreon::common::pool::io_context()},
+      _loop_timer{com::centreon::common::pool::io_context()},
+      _logger_sql{log_v2::instance().get(log_v2::SQL)},
+      _logger_sto{log_v2::instance().get(log_v2::PERFDATA)},
       _cv(queue_timer_duration,
           _max_pending_queries,
           "INSERT INTO customvariables "
@@ -172,16 +187,18 @@ stream::stream(const database_config& dbcfg,
           "value) VALUES {} "
           " ON DUPLICATE KEY UPDATE "
           "default_value=VALUES(default_VALUE),modified=VALUES(modified),type="
-          "VALUES(type),update_time=VALUES(update_time),value=VALUES(value)"),
+          "VALUES(type),update_time=VALUES(update_time),value=VALUES(value)",
+          _logger_sql),
       _cvs(queue_timer_duration,
            _max_pending_queries,
            "INSERT INTO customvariables "
            "(name,host_id,service_id,modified,update_time,value) VALUES {} "
            " ON DUPLICATE KEY UPDATE "
            "modified=VALUES(modified),update_time=VALUES(update_time),value="
-           "VALUES(value)"),
+           "VALUES(value)",
+           _logger_sql),
       _oldest_timestamp{std::numeric_limits<time_t>::max()} {
-  SPDLOG_LOGGER_DEBUG(log_v2::sql(), "unified sql: stream class instanciation");
+  SPDLOG_LOGGER_DEBUG(_logger_sql, "unified sql: stream class instanciation");
 
   // dedicated connections for data_bin and logs?
   unsigned nb_dedicated_connection = 0;
@@ -199,7 +216,7 @@ stream::stream(const database_config& dbcfg,
 
   if (nb_dedicated_connection > 0) {
     SPDLOG_LOGGER_INFO(
-        log_v2::sql(),
+        _logger_sql,
         "use of {} dedicated connection for logs and data_bin tables",
         nb_dedicated_connection);
     database_config dedicated_cfg(dbcfg);
@@ -219,33 +236,39 @@ stream::stream(const database_config& dbcfg,
   _action.resize(_mysql.connections_count());
 
   _bulk_prepared_statement = _mysql.support_bulk_statement();
-  log_v2::sql()->info("Unified sql stream connected to '{}' Server",
-                      _mysql.get_server_version());
+  _logger_sql->info("Unified sql stream connected to '{}' Server",
+                    _mysql.get_server_version());
 
   try {
     _init_statements();
     _load_caches();
   } catch (const std::exception& e) {
-    SPDLOG_LOGGER_ERROR(log_v2::sql(), "error while loading caches: {}",
+    SPDLOG_LOGGER_ERROR(_logger_sql, "error while loading caches: {}",
                         e.what());
     throw;
   }
-  std::lock_guard<std::mutex> l(_timer_m);
+  absl::MutexLock l(&_timer_m);
   _queues_timer.expires_after(std::chrono::seconds(queue_timer_duration));
-  _queues_timer.async_wait(
-      [this](const boost::system::error_code& err) { _check_queues(err); });
+  _queues_timer.async_wait([this](const boost::system::error_code& err) {
+    absl::ReaderMutexLock lck(&_barrier_timer_m);
+    _check_queues(err);
+  });
   _start_loop_timer();
-  SPDLOG_LOGGER_INFO(log_v2::sql(),
-                     "Unified sql stream running loop_interval={}",
+  SPDLOG_LOGGER_INFO(_logger_sql, "Unified sql stream running loop_interval={}",
                      _loop_timeout);
 }
 
 stream::~stream() noexcept {
-  std::lock_guard<std::mutex> l(_timer_m);
-  _group_clean_timer.cancel();
-  _queues_timer.cancel();
-  _loop_timer.cancel();
-  SPDLOG_LOGGER_DEBUG(log_v2::sql(), "unified sql: stream destruction");
+  {
+    absl::MutexLock l(&_timer_m);
+    _group_clean_timer.cancel();
+    _queues_timer.cancel();
+    _loop_timer.cancel();
+  }
+  /* Let's wait a little if one of the timers is working during the cancellation
+   */
+  absl::MutexLock lck(&_barrier_timer_m);
+  SPDLOG_LOGGER_DEBUG(_logger_sql, "unified sql: stream destruction");
 }
 
 void stream::_load_deleted_instances() {
@@ -260,7 +283,7 @@ void stream::_load_deleted_instances() {
       int32_t instance_id = res.value_as_i32(0);
       if (instance_id <= 0)
         SPDLOG_LOGGER_ERROR(
-            log_v2::sql(),
+            _logger_sql,
             "unified_sql: The 'instances' table contains rows with instance_id "
             "<= 0 ; you should remove them.");
       else
@@ -389,18 +412,18 @@ void stream::_load_caches() {
       if (host_id <= 0 || service_id <= 0) {
         if (host_id <= 0)
           SPDLOG_LOGGER_ERROR(
-              log_v2::sql(),
+              _logger_sql,
               "unified_sql: the 'index_data' table contains rows with host_id "
               "<= "
               "0, you should remove them.");
         if (service_id <= 0)
           SPDLOG_LOGGER_ERROR(
-              log_v2::sql(),
+              _logger_sql,
               "unified_sql: the 'index_data' table contains rows with "
               "service_id "
               "<= 0, you should remove them.");
       } else {
-        log_v2::perfdata()->debug(
+        _logger_sto->debug(
             "unified_sql: loaded index {} of ({}, {}) with rrd_len={}",
             info.index_id, host_id, service_id, info.rrd_retention);
         _index_cache[{host_id, service_id}] = std::move(info);
@@ -441,12 +464,12 @@ void stream::_load_caches() {
       else {
         if (host_id <= 0)
           SPDLOG_LOGGER_ERROR(
-              log_v2::sql(),
+              _logger_sql,
               "unified_sql: the 'hosts' table contains rows with host_id <= 0, "
               "you should remove them.");
         if (instance_id <= 0)
           SPDLOG_LOGGER_ERROR(
-              log_v2::sql(),
+              _logger_sql,
               "unified_sql: the 'hosts' table contains rows with instance_id "
               "<= 0, you should remove them.");
       }
@@ -466,7 +489,7 @@ void stream::_load_caches() {
         _hostgroup_cache.insert(hg_id);
       else
         SPDLOG_LOGGER_ERROR(
-            log_v2::sql(),
+            _logger_sql,
             "unified_sql: the table 'hostgroups' contains rows with "
             "hostgroup_id <= 0, you should remove them.");
     }
@@ -482,7 +505,7 @@ void stream::_load_caches() {
       int32_t sg_id = res.value_as_i32(0);
       if (sg_id <= 0)
         SPDLOG_LOGGER_ERROR(
-            log_v2::sql(),
+            _logger_sql,
             "unified_sql: the 'servicegroups' table contains rows with "
             "servicegroup_id <= 0, you should remove them.");
       else
@@ -513,9 +536,9 @@ void stream::_load_caches() {
 
         if (metric_id <= 0)
           SPDLOG_LOGGER_ERROR(
-              log_v2::sql(),
-              "unified_sql: the 'metrics' table contains row with metric_id {} "
-              "<= 0 ; you should remove it.", metric_id);
+              _logger_sql,
+              "unified_sql: the 'metrics' table contains row with metric_id "
+              "<= 0 ; you should remove them.");
         else {
           uint64_t index_id = res.value_as_u64(1);
           std::string metric_name = res.value_as_str(2);
@@ -589,7 +612,7 @@ void stream::update_metric_info_cache(uint64_t index_id,
   misc::read_lock lck(_metric_cache_m);
   auto it = _metric_cache.find({index_id, metric_name});
   if (it != _metric_cache.end()) {
-    log_v2::perfdata()->info(
+    _logger_sto->info(
         "unified sql: updating metric '{}' of id {} at index {} to "
         "metric_type {}",
         metric_name, metric_id, index_id, metric_type_name[metric_type]);
@@ -634,14 +657,14 @@ void stream::_finish_action(int32_t conn, uint32_t action) {
  *  events.
  */
 void stream::_finish_actions() {
-  SPDLOG_LOGGER_TRACE(log_v2::sql(), "unified sql: finish actions");
+  SPDLOG_LOGGER_TRACE(_logger_sql, "unified sql: finish actions");
   _mysql.commit();
   for (uint32_t& v : _action)
     v = actions::none;
   _ack += _processed;
   _processed = 0;
-  SPDLOG_LOGGER_TRACE(log_v2::sql(), "finish actions processed = {}",
-                      _processed);
+  SPDLOG_LOGGER_TRACE(_logger_sql, "finish actions processed = {}",
+                      static_cast<int>(_processed));
 }
 
 /**
@@ -697,7 +720,7 @@ int32_t stream::write(const std::shared_ptr<io::data>& data) {
   assert(data);
 
   SPDLOG_LOGGER_TRACE(
-      log_v2::sql(), "unified sql: write event category:{}, element:{}",
+      _logger_sql, "unified sql: write event category:{}, element:{}",
       category_of_type(data->type()), element_of_type(data->type()));
 
   uint32_t type = data->type();
@@ -707,18 +730,35 @@ int32_t stream::write(const std::shared_ptr<io::data>& data) {
     if (elem < neb_processing_table_size && neb_processing_table[elem]) {
       (this->*(neb_processing_table[elem]))(data);
     } else {
-      SPDLOG_LOGGER_ERROR(log_v2::sql(), "unknown neb event type: {}", elem);
+      SPDLOG_LOGGER_ERROR(_logger_sql, "unknown neb event type: {}", elem);
+    }
+  } else if (cat == io::bbdo) {
+    switch (elem) {
+      case bbdo::de_rebuild_graphs:
+        _rebuilder.rebuild_graphs(data);
+        break;
+      case bbdo::de_remove_graphs:
+        remove_graphs(data);
+        break;
+      case bbdo::de_remove_poller:
+        SPDLOG_LOGGER_INFO(_logger_sql, "remove poller...");
+        remove_poller(data);
+        break;
+      default:
+        SPDLOG_LOGGER_TRACE(
+            _logger_sql,
+            "unified sql: event of category bbdo and type {} thrown away ; no "
+            "need to store it in the database.",
+            type);
+    }
+  } else if (cat == io::local) {
+    if (elem == local::de_pb_stop) {
+      SPDLOG_LOGGER_INFO(_logger_sql, "poller stopped...");
+      process_stop(data);
     }
-  } else if (type == make_type(io::bbdo, bbdo::de_rebuild_graphs))
-    _rebuilder.rebuild_graphs(data);
-  else if (type == make_type(io::bbdo, bbdo::de_remove_graphs))
-    remove_graphs(data);
-  else if (type == make_type(io::bbdo, bbdo::de_remove_poller)) {
-    SPDLOG_LOGGER_INFO(log_v2::sql(), "remove poller...");
-    remove_poller(data);
   } else {
     SPDLOG_LOGGER_TRACE(
-        log_v2::sql(),
+        _logger_sql,
         "unified sql: event of type {} thrown away ; no need to store it in "
         "the database.",
         type);
@@ -755,16 +795,23 @@ class unified_muxer_filter : public multiplexing::muxer_filter {
     _mask[io::bbdo] |= 1ULL << bbdo::de_rebuild_graphs;
     _mask[io::bbdo] |= 1ULL << bbdo::de_remove_graphs;
     _mask[io::bbdo] |= 1ULL << bbdo::de_remove_poller;
+    _mask[io::local] |= 1ULL << local::de_pb_stop;
     _mask[io::extcmd] |= 1ULL << extcmd::de_pb_bench;
   }
 };
 
 constexpr unified_muxer_filter _muxer_filter;
+constexpr multiplexing::muxer_filter _forbidden_filter =
+    multiplexing::muxer_filter(_muxer_filter).reverse();
 
 const multiplexing::muxer_filter& stream::get_muxer_filter() {
   return _muxer_filter;
 }
 
+const multiplexing::muxer_filter& stream::get_forbidden_filter() {
+  return _forbidden_filter;
+}
+
 /**
  * @brief Flush the stream.
  *
@@ -777,8 +824,8 @@ int32_t stream::flush() {
   _ack -= retval;
   _pending_events -= retval;
   // Event acknowledgement.
-  SPDLOG_LOGGER_TRACE(log_v2::sql(), "SQL: {} / {} events acknowledged", retval,
-                      _pending_events);
+  SPDLOG_LOGGER_TRACE(_logger_sql, "SQL: {} / {} events acknowledged", retval,
+                      static_cast<int32_t>(_pending_events));
   return retval;
 }
 
@@ -804,6 +851,7 @@ bool stream::read(std::shared_ptr<io::data>& d, time_t deadline) {
  * @return the number of events to ack.
  */
 int32_t stream::stop() {
+  _logger_sql->trace("unified_sql::stream stop {}", static_cast<void*>(this));
   int32_t retval = flush();
   /* We give the order to stop the check_queues */
   _stop_check_queues = true;
@@ -811,23 +859,60 @@ int32_t stream::stop() {
   std::unique_lock<std::mutex> lck(_queues_m);
   if (_queues_cond_var.wait_for(lck, std::chrono::seconds(queue_timer_duration),
                                 [this] { return _check_queues_stopped; })) {
-    SPDLOG_LOGGER_INFO(log_v2::sql(), "SQL: stream correctly stopped");
+    SPDLOG_LOGGER_INFO(_logger_sql, "SQL: stream correctly stopped");
   } else {
-    SPDLOG_LOGGER_ERROR(log_v2::sql(),
+    SPDLOG_LOGGER_ERROR(_logger_sql,
                         "SQL: stream queues check still running...");
   }
 
   return retval;
 }
 
+/**
+ * @brief Function called when a poller is disconnected from Broker. It cleans
+ * hosts/services and instances in the storage database.
+ *
+ * @param d A pb_stop event with the instance ID.
+ */
+void stream::process_stop(const std::shared_ptr<io::data>& d) {
+  auto& stop = static_cast<local::pb_stop*>(d.get())->obj();
+  int32_t conn = _mysql.choose_connection_by_instance(stop.poller_id());
+  _finish_action(-1, actions::hosts | actions::acknowledgements |
+                         actions::modules | actions::downtimes |
+                         actions::comments | actions::servicegroups |
+                         actions::hostgroups | actions::service_dependencies |
+                         actions::host_dependencies);
+
+  // Log message.
+  _logger_sql->info("unified_sql: Disabling poller (id: {}, running: no)",
+                    stop.poller_id());
+
+  // Clean tables.
+  _clean_tables(stop.poller_id());
+
+  // Processing.
+  if (_is_valid_poller(stop.poller_id())) {
+    // Prepare queries.
+    if (!_instance_insupdate.prepared()) {
+      std::string query(fmt::format(
+          "UPDATE instances SET end_time={}, running=0 WHERE instance_id={}",
+          time(nullptr), stop.poller_id()));
+      _mysql.run_query(query, database::mysql_error::clean_hosts_services,
+                       conn);
+      _add_action(conn, actions::instances);
+    }
+  }
+}
+
 /**
  * @brief process a remove graphs message.
  *
  * @param d The BBDO message with all the metrics/indexes to remove.
  */
 void stream::remove_graphs(const std::shared_ptr<io::data>& d) {
-  SPDLOG_LOGGER_INFO(log_v2::sql(), "remove graphs call");
-  asio::post(pool::instance().io_context(), [this, data = d] {
+  SPDLOG_LOGGER_INFO(_logger_sql, "remove graphs call");
+  asio::post(com::centreon::common::pool::instance().io_context(), [this,
+                                                                    data = d] {
     mysql ms(_dbcfg);
     bbdo::pb_remove_graphs* ids =
         static_cast<bbdo::pb_remove_graphs*>(data.get());
@@ -856,17 +941,17 @@ void stream::remove_graphs(const std::shared_ptr<io::data>& d) {
           if (mid <= 0 || host_id <= 0 || service_id <= 0) {
             if (mid <= 0)
               SPDLOG_LOGGER_ERROR(
-                  log_v2::sql(),
+                  _logger_sql,
                   "unified_sql: the 'metrics' table contains rows with "
                   "metric_id <= 0 ; you should remove them.");
             if (host_id <= 0)
-              SPDLOG_LOGGER_ERROR(log_v2::sql(),
+              SPDLOG_LOGGER_ERROR(_logger_sql,
                                   "unified_sql: the 'metrics' table "
                                   "contains rows with host_id "
                                   "<= 0 ; you should remove them.");
             if (service_id <= 0)
               SPDLOG_LOGGER_ERROR(
-                  log_v2::sql(),
+                  _logger_sql,
                   "unified_sql: the 'metrics' table contains rows with "
                   "service_id <= 0 ; you should remove them.");
           } else {
@@ -893,11 +978,10 @@ void stream::remove_graphs(const std::shared_ptr<io::data>& d) {
         while (ms.fetch_row(res)) {
           int32_t metric_id = res.value_as_i32(1);
           if (metric_id <= 0)
-            SPDLOG_LOGGER_ERROR(
-                log_v2::sql(),
-                "unified_sql: the 'metrics' table contains rows with metric_id "
-                "{} <= 0 ; you should remove it.",
-                metric_id);
+            SPDLOG_LOGGER_ERROR(_logger_sql,
+                                "unified_sql: the 'metrics' table contains "
+                                "rows with metric_id "
+                                "<= 0 ; you should remove them.");
           else {
             metrics_to_delete.insert(metric_id);
             _metric_cache.erase({res.value_as_u64(0), res.value_as_str(2)});
@@ -905,7 +989,7 @@ void stream::remove_graphs(const std::shared_ptr<io::data>& d) {
         }
       }
     } catch (const std::exception& e) {
-      SPDLOG_LOGGER_ERROR(log_v2::sql(),
+      SPDLOG_LOGGER_ERROR(_logger_sql,
                           "could not query index / metrics table(s) to get "
                           "index to delete: "
                           "{} ",
@@ -914,7 +998,7 @@ void stream::remove_graphs(const std::shared_ptr<io::data>& d) {
 
     std::string mids_str{fmt::format("{}", fmt::join(metrics_to_delete, ","))};
     if (!metrics_to_delete.empty()) {
-      SPDLOG_LOGGER_INFO(log_v2::sql(), "metrics {} erased from database",
+      SPDLOG_LOGGER_INFO(_logger_sql, "metrics {} erased from database",
                          mids_str);
       ms.run_query(
           fmt::format("DELETE FROM metrics WHERE metric_id in ({})", mids_str),
@@ -922,7 +1006,7 @@ void stream::remove_graphs(const std::shared_ptr<io::data>& d) {
     }
     std::string ids_str{fmt::format("{}", fmt::join(indexes_to_delete, ","))};
     if (!indexes_to_delete.empty()) {
-      SPDLOG_LOGGER_INFO(log_v2::sql(), "indexes {} erased from database",
+      SPDLOG_LOGGER_INFO(_logger_sql, "indexes {} erased from database",
                          ids_str);
       ms.run_query(
           fmt::format("DELETE FROM index_data WHERE id in ({})", ids_str),
@@ -936,13 +1020,13 @@ void stream::remove_graphs(const std::shared_ptr<io::data>& d) {
       for (uint64_t i : indexes_to_delete)
         rmg->mut_obj().add_index_ids(i);
       SPDLOG_LOGGER_INFO(
-          log_v2::sql(),
+          _logger_sql,
           "publishing pb remove graph with {} metrics and {} indexes",
           metrics_to_delete.size(), indexes_to_delete.size());
       multiplexing::publisher().write(rmg);
     } else
       SPDLOG_LOGGER_INFO(
-          log_v2::sql(),
+          _logger_sql,
           "metrics {} and indexes {} do not appear in the storage database",
           mids_str, ids_str);
   });
@@ -978,9 +1062,8 @@ void stream::remove_poller(const std::shared_ptr<io::data>& d) {
       }
       if (count == 0) {
         SPDLOG_LOGGER_WARN(
-            log_v2::sql(),
-            "Unable to remove poller '{}', {} not running found in the "
-            "database",
+            _logger_sql,
+            "Unable to remove poller '{}', {} running found in the database",
             poller.obj().str(), count == 0 ? "none" : "more than one");
         std::promise<database::mysql_result> promise;
         std::future<mysql_result> future = promise.get_future();
@@ -994,7 +1077,7 @@ void stream::remove_poller(const std::shared_ptr<io::data>& d) {
           if (!config::applier::state::instance().has_connection_from_poller(
                   res.value_as_u64(0))) {
             SPDLOG_LOGGER_WARN(
-                log_v2::sql(),
+                _logger_sql,
                 "The poller '{}' id {} is not connected (even if it looks "
                 "running or not deleted)",
                 poller.obj().str(), res.value_as_u64(0));
@@ -1018,8 +1101,8 @@ void stream::remove_poller(const std::shared_ptr<io::data>& d) {
       }
       if (count == 0) {
         SPDLOG_LOGGER_WARN(
-            log_v2::sql(),
-            "Unable to remove poller {}, {} not running found in the "
+            _logger_sql,
+            "Unable to remove poller {}, {} running found in the "
             "database",
             poller.obj().idx(), count == 0 ? "none" : "more than one");
         std::promise<database::mysql_result> promise;
@@ -1034,7 +1117,7 @@ void stream::remove_poller(const std::shared_ptr<io::data>& d) {
           if (!config::applier::state::instance().has_connection_from_poller(
                   poller.obj().idx())) {
             SPDLOG_LOGGER_WARN(
-                log_v2::sql(),
+                _logger_sql,
                 "The poller '{}' id {} is not connected (even if it looks "
                 "running or not deleted)",
                 res.value_as_str(0), poller.obj().idx());
@@ -1047,17 +1130,17 @@ void stream::remove_poller(const std::shared_ptr<io::data>& d) {
 
     for (uint64_t id : ids) {
       conn = _mysql.choose_connection_by_instance(id);
-      SPDLOG_LOGGER_INFO(log_v2::sql(), "unified sql: removing poller {}", id);
+      SPDLOG_LOGGER_INFO(_logger_sql, "unified sql: removing poller {}", id);
       _mysql.run_query(
           fmt::format("DELETE FROM instances WHERE instance_id={}", id),
           database::mysql_error::delete_poller, conn);
-      SPDLOG_LOGGER_TRACE(log_v2::sql(),
-                          "unified sql: removing poller {} hosts", id);
+      SPDLOG_LOGGER_TRACE(_logger_sql, "unified sql: removing poller {} hosts",
+                          id);
       _mysql.run_query(
           fmt::format("DELETE FROM hosts WHERE instance_id={}", id),
           database::mysql_error::delete_poller, conn);
 
-      SPDLOG_LOGGER_TRACE(log_v2::sql(),
+      SPDLOG_LOGGER_TRACE(_logger_sql,
                           "unified sql: removing poller {} resources", id);
       _mysql.run_query(
           fmt::format("DELETE FROM resources WHERE poller_id={}", id),
@@ -1066,9 +1149,8 @@ void stream::remove_poller(const std::shared_ptr<io::data>& d) {
     }
     _clear_instances_cache(ids);
   } catch (const std::exception& e) {
-    SPDLOG_LOGGER_ERROR(log_v2::sql(),
-                        "Error encountered while removing a poller: {}",
-                        e.what());
+    SPDLOG_LOGGER_ERROR(
+        _logger_sql, "Error encountered while removing a poller: {}", e.what());
   }
 }
 
@@ -1114,7 +1196,7 @@ void stream::_clear_instances_cache(const std::list<uint64_t>& ids) {
 }
 
 void stream::update() {
-  SPDLOG_LOGGER_INFO(log_v2::sql(), "unified_sql stream update");
+  SPDLOG_LOGGER_INFO(_logger_sql, "unified_sql stream update");
   _check_deleted_index();
   _check_rebuild_index();
 }
@@ -1125,8 +1207,12 @@ void stream::_start_loop_timer() {
     if (err) {
       return;
     }
+    absl::ReaderMutexLock lck(&_barrier_timer_m);
     _update_hosts_and_services_of_unresponsive_instances();
-    _start_loop_timer();
+    {
+      absl::MutexLock l(&_timer_m);
+      _start_loop_timer();
+    }
   });
 }
 
@@ -1313,20 +1399,36 @@ void stream::_init_statements() {
       "last_check=?,"                 // 9: last_check
       "output=? "                     // 10: output
       "WHERE id=? AND parent_id=?");  // 11, 12: service_id and host_id
+  const std::string host_exe_dep_query(
+      "INSERT INTO hosts_hosts_dependencies (dependent_host_id, host_id, "
+      "dependency_period, execution_failure_options, inherits_parent) "
+      "VALUES(?,?,?,?,?) ON DUPLICATE KEY UPDATE "
+      "dependency_period=VALUES(dependency_period), "
+      "execution_failure_options=VALUES(execution_failure_options), "
+      "inherits_parent=VALUES(inherits_parent)");
+  _host_exe_dependency_insupdate = _mysql.prepare_query(host_exe_dep_query);
+  const std::string host_notif_dep_query(
+      "INSERT INTO hosts_hosts_dependencies (dependent_host_id, host_id, "
+      "dependency_period, notification_failure_options, inherits_parent) "
+      "VALUES(?,?,?,?,?) ON DUPLICATE KEY UPDATE "
+      "dependency_period=VALUES(dependency_period), "
+      "notification_failure_options=VALUES(notification_failure_options), "
+      "inherits_parent=VALUES(inherits_parent)");
+  _host_notif_dependency_insupdate = _mysql.prepare_query(host_notif_dep_query);
   if (_store_in_hosts_services) {
     if (_bulk_prepared_statement) {
       auto hu = std::make_unique<database::mysql_bulk_stmt>(hscr_query);
       _mysql.prepare_statement(*hu);
-      _hscr_bind = std::make_unique<bulk_bind>(_dbcfg.get_connections_count(),
-                                               dt_queue_timer_duration,
-                                               _max_pending_queries, *hu);
+      _hscr_bind = std::make_unique<bulk_bind>(
+          _dbcfg.get_connections_count(), dt_queue_timer_duration,
+          _max_pending_queries, *hu, _logger_sql);
       _hscr_update = std::move(hu);
 
       auto su = std::make_unique<database::mysql_bulk_stmt>(sscr_query);
       _mysql.prepare_statement(*su);
-      _sscr_bind = std::make_unique<bulk_bind>(_dbcfg.get_connections_count(),
-                                               dt_queue_timer_duration,
-                                               _max_pending_queries, *su);
+      _sscr_bind = std::make_unique<bulk_bind>(
+          _dbcfg.get_connections_count(), dt_queue_timer_duration,
+          _max_pending_queries, *su, _logger_sql);
       _sscr_update = std::move(su);
     } else {
       _hscr_update = std::make_unique<database::mysql_stmt>(hscr_query);
@@ -1343,7 +1445,7 @@ void stream::_init_statements() {
       _mysql.prepare_statement(*hu);
       _hscr_resources_bind = std::make_unique<bulk_bind>(
           _dbcfg.get_connections_count(), dt_queue_timer_duration,
-          _max_pending_queries, *hu);
+          _max_pending_queries, *hu, _logger_sql);
       _hscr_resources_update = std::move(hu);
 
       auto su =
@@ -1351,7 +1453,7 @@ void stream::_init_statements() {
       _mysql.prepare_statement(*su);
       _sscr_resources_bind = std::make_unique<bulk_bind>(
           _dbcfg.get_connections_count(), dt_queue_timer_duration,
-          _max_pending_queries, *su);
+          _max_pending_queries, *su, _logger_sql);
       _sscr_resources_update = std::move(su);
     } else {
       _hscr_resources_update =
