@@ -1,21 +1,22 @@
-/*
-** Copyright 2019-2022 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2019-2022 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
+#include <absl/synchronization/mutex.h>
 #include <fmt/format.h>
 
 #include <cfloat>
@@ -29,15 +30,15 @@
 #include "bbdo/storage/remove_graph.hh"
 #include "bbdo/storage/status.hh"
 #include "com/centreon/broker/cache/global_cache.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/misc/misc.hh"
-#include "com/centreon/broker/misc/perfdata.hh"
 #include "com/centreon/broker/misc/shared_mutex.hh"
 #include "com/centreon/broker/misc/string.hh"
 #include "com/centreon/broker/neb/events.hh"
 #include "com/centreon/broker/sql/table_max_size.hh"
 #include "com/centreon/broker/unified_sql/internal.hh"
 #include "com/centreon/broker/unified_sql/stream.hh"
+#include "com/centreon/common/perfdata.hh"
+#include "com/centreon/common/utf8.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
 
 using namespace com::centreon::exceptions;
@@ -82,13 +83,13 @@ void stream::_unified_sql_process_pb_service_status(
   uint64_t host_id = ss.host_id(), service_id = ss.service_id();
 
   SPDLOG_LOGGER_DEBUG(
-      log_v2::perfdata(),
+      _logger_sto,
       "unified sql::_unified_sql service_status processing: host_id:{}, "
       "service_id:{}",
       host_id, service_id);
   auto it_index_cache = _index_cache.find({host_id, service_id});
   if (it_index_cache == _index_cache.end()) {
-    log_v2::sql()->critical(
+    _logger_sql->critical(
         "sql: could not find index for service({}, {}) - maybe the poller with "
         "that service should be restarted",
         host_id, service_id);
@@ -111,7 +112,7 @@ void stream::_unified_sql_process_pb_service_status(
   index_locked = it_index_cache->second.locked;
   uint32_t interval = it_index_cache->second.interval * _interval_length;
   SPDLOG_LOGGER_DEBUG(
-      log_v2::perfdata(),
+      _logger_sto,
       "unified sql: host_id:{}, service_id:{} - index already in cache "
       "- index_id {}, rrd_len {}, serv_interval {}, interval {}",
       host_id, service_id, index_id, rrd_len, it_index_cache->second.interval,
@@ -120,7 +121,7 @@ void stream::_unified_sql_process_pb_service_status(
   if (index_id) {
     /* Generate status event */
     SPDLOG_LOGGER_DEBUG(
-        log_v2::perfdata(),
+        _logger_sto,
         "unified sql: host_id:{}, service_id:{} - generating status event "
         "with index_id {}, rrd_len: {}",
         host_id, service_id, index_id, rrd_len);
@@ -150,12 +151,19 @@ void stream::_unified_sql_process_pb_service_status(
 
       /* Parse perfdata. */
       _finish_action(-1, actions::metrics);
-      std::list<misc::perfdata> pds{misc::parse_perfdata(
-          ss.host_id(), ss.service_id(), ss.perfdata().c_str())};
+      std::list<common::perfdata> pds{common::perfdata::parse_perfdata(
+          ss.host_id(), ss.service_id(), ss.perfdata().c_str(), _logger_sto)};
 
       std::deque<std::shared_ptr<io::data>> to_publish;
       for (auto& pd : pds) {
         misc::read_lock rlck(_metric_cache_m);
+        pd.resize_name(common::adjust_size_utf8(
+            pd.name(), get_centreon_storage_metrics_col_size(
+                           centreon_storage_metrics_metric_name)));
+        pd.resize_unit(common::adjust_size_utf8(
+            pd.unit(), get_centreon_storage_metrics_col_size(
+                           centreon_storage_metrics_unit_name)));
+
         auto it_index_cache = _metric_cache.find({index_id, pd.name()});
 
         /* The cache does not contain this metric */
@@ -164,7 +172,7 @@ void stream::_unified_sql_process_pb_service_status(
         if (it_index_cache == _metric_cache.end()) {
           rlck.unlock();
           SPDLOG_LOGGER_DEBUG(
-              log_v2::perfdata(),
+              _logger_sto,
               "unified sql: no metrics corresponding to index {} and "
               "perfdata '{}' found in cache",
               index_id, pd.name());
@@ -198,7 +206,7 @@ void stream::_unified_sql_process_pb_service_status(
             metric_id = future.get();
 
             // Insert metric in cache.
-            log_v2::perfdata()->info(
+            _logger_sto->info(
                 "unified sql: new metric {} for index {} and perfdata "
                 "'{}'",
                 metric_id, index_id, pd.name());
@@ -221,7 +229,7 @@ void stream::_unified_sql_process_pb_service_status(
             std::lock_guard<misc::shared_mutex> lock(_metric_cache_m);
             _metric_cache[{index_id, pd.name()}] = info;
           } catch (std::exception const& e) {
-            log_v2::perfdata()->error(
+            _logger_sto->error(
                 "unified sql: failed to create metric '{}' with type {}, "
                 "value {}, unit_name {}, warn {}, warn_low {}, warn_mode {}, "
                 "crit {}, crit_low {}, crit_mode {}, min {} and max {}",
@@ -242,11 +250,11 @@ void stream::_unified_sql_process_pb_service_status(
           else
             need_metric_mapping = false;
 
-          pd.value_type(static_cast<misc::perfdata::data_type>(
+          pd.value_type(static_cast<common::perfdata::data_type>(
               it_index_cache->second.type));
 
           SPDLOG_LOGGER_DEBUG(
-              log_v2::perfdata(),
+              _logger_sto,
               "unified sql: metric {} concerning index {}, perfdata "
               "'{}' found in cache",
               it_index_cache->second.metric_id, index_id, pd.name());
@@ -263,7 +271,7 @@ void stream::_unified_sql_process_pb_service_status(
               it_index_cache->second.crit_mode != pd.critical_mode() ||
               !check_equality(it_index_cache->second.min, pd.min()) ||
               !check_equality(it_index_cache->second.max, pd.max())) {
-            log_v2::perfdata()->info(
+            _logger_sto->info(
                 "unified sql: updating metric {} of index {}, perfdata "
                 "'{}' with unit: {}, warning: {}:{}, critical: {}:{}, min: "
                 "{}, max: {}",
@@ -286,8 +294,7 @@ void stream::_unified_sql_process_pb_service_status(
               _metrics[it_index_cache->second.metric_id] =
                   it_index_cache->second;
             }
-            SPDLOG_LOGGER_DEBUG(log_v2::perfdata(),
-                                "new metric with metric_id={}",
+            SPDLOG_LOGGER_DEBUG(_logger_sto, "new metric with metric_id={}",
                                 it_index_cache->second.metric_id);
           }
         }
@@ -320,7 +327,7 @@ void stream::_unified_sql_process_pb_service_status(
               else
                 b.set_value_as_f32(3, pd.value());
               SPDLOG_LOGGER_TRACE(
-                  log_v2::sql(),
+                  _logger_sql,
                   "New value {} inserted on metric {} with state {}",
                   pd.value(), metric_id, ss.state());
               b.next_row();
@@ -330,7 +337,7 @@ void stream::_unified_sql_process_pb_service_status(
             std::string row;
             if (std::isinf(pd.value()))
               row = fmt::format("({},{},'{}',{})", metric_id, ss.last_check(),
-                                ss.state(),
+                                static_cast<uint32_t>(ss.state()),
                                 pd.value() < 0.0 ? -FLT_MAX : FLT_MAX);
             else if (std::isnan(pd.value()))
               row = fmt::format("({},{},'{}',NULL)", metric_id, ss.last_check(),
@@ -356,7 +363,7 @@ void stream::_unified_sql_process_pb_service_status(
           m.set_host_id(ss.host_id());
           m.set_service_id(ss.service_id());
           SPDLOG_LOGGER_DEBUG(
-              log_v2::perfdata(),
+              _logger_sto,
               "unified sql: generating perfdata event for metric {} "
               "(name '{}', time {}, value {}, rrd_len {}, data_type {})",
               m.metric_id(), pd.name(), m.time(), m.value(), rrd_len,
@@ -364,7 +371,7 @@ void stream::_unified_sql_process_pb_service_status(
           to_publish.emplace_back(std::move(perf));
         } else {
           SPDLOG_LOGGER_TRACE(
-              log_v2::perfdata(),
+              _logger_sto,
               "unified sql: index {} is locked, so metric {} event not sent "
               "to rrd",
               index_id, metric_id);
@@ -389,7 +396,7 @@ void stream::_unified_sql_process_service_status(
   uint64_t host_id = ss.host_id, service_id = ss.service_id;
 
   SPDLOG_LOGGER_DEBUG(
-      log_v2::perfdata(),
+      _logger_sto,
       "unified sql::_unified_sql_process_service_status(): host_id:{}, "
       "service_id:{}",
       host_id, service_id);
@@ -413,7 +420,7 @@ void stream::_unified_sql_process_service_status(
     }
 
     /* Insert index in cache. */
-    log_v2::perfdata()->info(
+    _logger_sto->info(
         "unified sql: add_metric_in_cache: index {}, for host_id {} and "
         "service_id {}",
         index_id, host_id, service_id);
@@ -430,7 +437,7 @@ void stream::_unified_sql_process_service_status(
     _index_cache[{host_id, service_id}] = std::move(info);
     rrd_len = _rrd_len;
     SPDLOG_LOGGER_DEBUG(
-        log_v2::perfdata(),
+        _logger_sto,
         "add metric in cache: (host: {}, service: {}, index: {}, returned "
         "rrd_len {}",
         ss.host_name, ss.service_description, index_id, rrd_len);
@@ -446,7 +453,7 @@ void stream::_unified_sql_process_service_status(
   if (it_index_cache == _index_cache.end()) {
     _finish_action(-1, actions::index_data);
     SPDLOG_LOGGER_DEBUG(
-        log_v2::perfdata(),
+        _logger_sto,
         "unified sql::_unified_sql_process_service_status(): host_id:{}, "
         "service_id:{} - index not found in cache",
         host_id, service_id);
@@ -454,10 +461,10 @@ void stream::_unified_sql_process_service_status(
     if (!_index_data_insert.prepared())
       _index_data_insert = _mysql.prepare_query(_index_data_insert_request);
 
-    fmt::string_view hv(misc::string::truncate(
+    fmt::string_view hv(common::truncate_utf8(
         ss.host_name, get_centreon_storage_index_data_col_size(
                           centreon_storage_index_data_host_name)));
-    fmt::string_view sv(misc::string::truncate(
+    fmt::string_view sv(common::truncate_utf8(
         ss.service_description,
         get_centreon_storage_index_data_col_size(
             centreon_storage_index_data_service_description)));
@@ -482,7 +489,7 @@ void stream::_unified_sql_process_service_status(
     rrd_len = it_index_cache->second.rrd_retention;
     index_locked = it_index_cache->second.locked;
     SPDLOG_LOGGER_DEBUG(
-        log_v2::perfdata(),
+        _logger_sto,
         "unified sql: host_id:{}, service_id:{} - index already in cache "
         "- index_id {}, rrd_len {}",
         host_id, service_id, index_id, rrd_len);
@@ -496,7 +503,7 @@ void stream::_unified_sql_process_service_status(
 
     /* Generate status event */
     SPDLOG_LOGGER_DEBUG(
-        log_v2::perfdata(),
+        _logger_sto,
         "unified sql: host_id:{}, service_id:{} - generating status event "
         "with index_id {}, rrd_len: {}",
         host_id, service_id, index_id, rrd_len);
@@ -521,12 +528,19 @@ void stream::_unified_sql_process_service_status(
 
       /* Parse perfdata. */
       _finish_action(-1, actions::metrics);
-      std::list<misc::perfdata> pds{misc::parse_perfdata(
-          ss.host_id, ss.service_id, ss.perf_data.c_str())};
+      std::list<common::perfdata> pds{common::perfdata::parse_perfdata(
+          ss.host_id, ss.service_id, ss.perf_data.c_str(), _logger_sto)};
 
       std::deque<std::shared_ptr<io::data>> to_publish;
       for (auto& pd : pds) {
         misc::read_lock rlck(_metric_cache_m);
+        pd.resize_name(common::adjust_size_utf8(
+            pd.name(), get_centreon_storage_metrics_col_size(
+                           centreon_storage_metrics_metric_name)));
+        pd.resize_unit(common::adjust_size_utf8(
+            pd.unit(), get_centreon_storage_metrics_col_size(
+                           centreon_storage_metrics_unit_name)));
+
         auto it_index_cache = _metric_cache.find({index_id, pd.name()});
 
         /* The cache does not contain this metric */
@@ -535,7 +549,7 @@ void stream::_unified_sql_process_service_status(
         if (it_index_cache == _metric_cache.end()) {
           rlck.unlock();
           SPDLOG_LOGGER_DEBUG(
-              log_v2::perfdata(),
+              _logger_sto,
               "unified sql: no metrics corresponding to index {} and "
               "perfdata '{}' found in cache",
               index_id, pd.name());
@@ -569,7 +583,7 @@ void stream::_unified_sql_process_service_status(
             metric_id = future.get();
 
             // Insert metric in cache.
-            log_v2::perfdata()->info(
+            _logger_sto->info(
                 "unified sql: new metric {} for index {} and perfdata "
                 "'{}'",
                 metric_id, index_id, pd.name());
@@ -592,7 +606,7 @@ void stream::_unified_sql_process_service_status(
             std::lock_guard<misc::shared_mutex> lock(_metric_cache_m);
             _metric_cache[{index_id, pd.name()}] = info;
           } catch (std::exception const& e) {
-            log_v2::perfdata()->error(
+            _logger_sto->error(
                 "unified sql: failed to create metric '{}' with type {}, "
                 "value {}, unit_name {}, warn {}, warn_low {}, warn_mode {}, "
                 "crit {}, crit_low {}, crit_mode {}, min {} and max {}",
@@ -613,11 +627,11 @@ void stream::_unified_sql_process_service_status(
           else
             need_metric_mapping = false;
 
-          pd.value_type(static_cast<misc::perfdata::data_type>(
+          pd.value_type(static_cast<common::perfdata::data_type>(
               it_index_cache->second.type));
 
           SPDLOG_LOGGER_DEBUG(
-              log_v2::perfdata(),
+              _logger_sto,
               "unified sql: metric {} concerning index {}, perfdata "
               "'{}' found in cache",
               it_index_cache->second.metric_id, index_id, pd.name());
@@ -634,7 +648,7 @@ void stream::_unified_sql_process_service_status(
               it_index_cache->second.crit_mode != pd.critical_mode() ||
               !check_equality(it_index_cache->second.min, pd.min()) ||
               !check_equality(it_index_cache->second.max, pd.max())) {
-            log_v2::perfdata()->info(
+            _logger_sto->info(
                 "unified sql: updating metric {} of index {}, perfdata "
                 "'{}' with unit: {}, warning: {}:{}, critical: {}:{}, min: "
                 "{}, max: {}",
@@ -657,8 +671,7 @@ void stream::_unified_sql_process_service_status(
               _metrics[it_index_cache->second.metric_id] =
                   it_index_cache->second;
             }
-            SPDLOG_LOGGER_DEBUG(log_v2::perfdata(),
-                                "new metric with metric_id={}",
+            SPDLOG_LOGGER_DEBUG(_logger_sto, "new metric with metric_id={}",
                                 it_index_cache->second.metric_id);
           }
         }
@@ -713,9 +726,9 @@ void stream::_unified_sql_process_service_status(
               ss.host_id, ss.service_id, pd.name(), ss.last_check,
               static_cast<uint32_t>(ss.check_interval * _interval_length),
               false, metric_id, rrd_len, pd.value(),
-              static_cast<misc::perfdata::data_type>(pd.value_type()))};
+              static_cast<common::perfdata::data_type>(pd.value_type()))};
           SPDLOG_LOGGER_DEBUG(
-              log_v2::perfdata(),
+              _logger_sto,
               "unified sql: generating perfdata event for metric {} "
               "(name '{}', time {}, value {}, rrd_len {}, data_type {})",
               perf->metric_id, perf->name, perf->time, perf->value, rrd_len,
@@ -782,7 +795,7 @@ void stream::_update_metrics() {
         fmt::join(m, ",")));
     int32_t conn = _mysql.choose_best_connection(-1);
     _finish_action(-1, actions::metrics);
-    SPDLOG_LOGGER_TRACE(log_v2::sql(), "Send query: {}", query);
+    SPDLOG_LOGGER_TRACE(_logger_sql, "Send query: {}", query);
     _mysql.run_query(query, database::mysql_error::update_metrics, conn);
     _add_action(conn, actions::metrics);
   }
@@ -790,8 +803,8 @@ void stream::_update_metrics() {
 
 void stream::_check_queues(boost::system::error_code ec) {
   if (ec)
-    log_v2::sql()->error(
-        "unified_sql: the queues check encountered an error: {}", ec.message());
+    _logger_sql->error("unified_sql: the queues check encountered an error: {}",
+                       ec.message());
   else {
     time_t now = time(nullptr);
     size_t sz_metrics;
@@ -810,7 +823,7 @@ void stream::_check_queues(boost::system::error_code ec) {
         if (_store_in_hosts_services) {
           if (_hscr_bind) {
             SPDLOG_LOGGER_TRACE(
-                log_v2::sql(),
+                _logger_sql,
                 "Check if some statements are ready,  hscr_bind connections "
                 "count "
                 "= {}",
@@ -819,7 +832,7 @@ void stream::_check_queues(boost::system::error_code ec) {
                  conn++) {
               if (_hscr_bind->ready(conn)) {
                 SPDLOG_LOGGER_DEBUG(
-                    log_v2::sql(),
+                    _logger_sql,
                     "Sending {} hosts rows of host status on connection {}",
                     _hscr_bind->size(conn), conn);
                 // Setting the good bind to the stmt
@@ -834,7 +847,7 @@ void stream::_check_queues(boost::system::error_code ec) {
           }
           if (_sscr_bind) {
             SPDLOG_LOGGER_TRACE(
-                log_v2::sql(),
+                _logger_sql,
                 "Check if some statements are ready,  sscr_bind connections "
                 "count "
                 "= {}",
@@ -842,7 +855,7 @@ void stream::_check_queues(boost::system::error_code ec) {
             for (uint32_t conn = 0; conn < _sscr_bind->connections_count();
                  conn++) {
               if (_sscr_bind->ready(conn)) {
-                SPDLOG_LOGGER_DEBUG(log_v2::sql(),
+                SPDLOG_LOGGER_DEBUG(_logger_sql,
                                     "Sending {} services rows of service "
                                     "status on connection {}",
                                     _sscr_bind->size(conn), conn);
@@ -863,7 +876,7 @@ void stream::_check_queues(boost::system::error_code ec) {
                  conn < _hscr_resources_bind->connections_count(); conn++) {
               if (_hscr_resources_bind->ready(conn)) {
                 SPDLOG_LOGGER_DEBUG(
-                    log_v2::sql(),
+                    _logger_sql,
                     "Sending {} host rows of resource status on connection {}",
                     _hscr_resources_bind->size(conn), conn);
                 // Setting the good bind to the stmt
@@ -880,7 +893,7 @@ void stream::_check_queues(boost::system::error_code ec) {
             for (uint32_t conn = 0;
                  conn < _sscr_resources_bind->connections_count(); conn++) {
               if (_sscr_resources_bind->ready(conn)) {
-                SPDLOG_LOGGER_DEBUG(log_v2::sql(),
+                SPDLOG_LOGGER_DEBUG(_logger_sql,
                                     "Sending {} service rows of resource "
                                     "status on connection {}",
                                     _sscr_resources_bind->size(conn), conn);
@@ -902,7 +915,7 @@ void stream::_check_queues(boost::system::error_code ec) {
       {
         std::lock_guard<database::bulk_or_multi> lck(*_perfdata_query);
         if (_perfdata_query->ready()) {
-          SPDLOG_LOGGER_DEBUG(log_v2::sql(), "{} new perfdata inserted",
+          SPDLOG_LOGGER_DEBUG(_logger_sql, "{} new perfdata inserted",
                               _perfdata_query->row_count());
           _perfdata_query->execute(
               _dedicated_connections ? *_dedicated_connections : _mysql);
@@ -919,7 +932,7 @@ void stream::_check_queues(boost::system::error_code ec) {
 
       bool customvar_done = false;
       if (_cv.ready()) {
-        SPDLOG_LOGGER_DEBUG(log_v2::sql(), "{} new custom variables inserted",
+        SPDLOG_LOGGER_DEBUG(_logger_sql, "{} new custom variables inserted",
                             _cv.size());
         std::string query = _cv.get_query();
         int32_t conn =
@@ -931,9 +944,8 @@ void stream::_check_queues(boost::system::error_code ec) {
       }
 
       if (_cvs.ready()) {
-        SPDLOG_LOGGER_DEBUG(log_v2::sql(),
-                            "{} new custom variable status inserted",
-                            _cvs.size());
+        SPDLOG_LOGGER_DEBUG(
+            _logger_sql, "{} new custom variable status inserted", _cvs.size());
         std::string query = _cvs.get_query();
         int32_t conn =
             special_conn::custom_variable % _mysql.connections_count();
@@ -947,7 +959,7 @@ void stream::_check_queues(boost::system::error_code ec) {
       {
         std::lock_guard<database::bulk_or_multi> lck(*_downtimes);
         if (_downtimes->ready()) {
-          SPDLOG_LOGGER_DEBUG(log_v2::sql(), "{} new downtimes inserted",
+          SPDLOG_LOGGER_DEBUG(_logger_sql, "{} new downtimes inserted",
                               _downtimes->row_count());
           _finish_action(-1, actions::hosts | actions::instances |
                                  actions::downtimes | actions::host_parents |
@@ -965,7 +977,7 @@ void stream::_check_queues(boost::system::error_code ec) {
       {
         std::lock_guard<database::bulk_or_multi> lck(*_comments);
         if (_comments->ready()) {
-          SPDLOG_LOGGER_DEBUG(log_v2::sql(), "{} new comments inserted",
+          SPDLOG_LOGGER_DEBUG(_logger_sql, "{} new comments inserted",
                               _comments->row_count());
           int32_t conn = special_conn::comment % _mysql.connections_count();
           _comments->execute(_mysql, database::mysql_error::store_downtime,
@@ -979,7 +991,7 @@ void stream::_check_queues(boost::system::error_code ec) {
       {
         std::lock_guard<database::bulk_or_multi> lck(*_logs);
         if (_logs->ready()) {
-          SPDLOG_LOGGER_DEBUG(log_v2::sql(), "{} new logs inserted",
+          SPDLOG_LOGGER_DEBUG(_logger_sql, "{} new logs inserted",
                               _logs->row_count());
           if (_dedicated_connections)
             _logs->execute(*_dedicated_connections,
@@ -992,7 +1004,7 @@ void stream::_check_queues(boost::system::error_code ec) {
       }
 
       // End.
-      SPDLOG_LOGGER_DEBUG(log_v2::sql(),
+      SPDLOG_LOGGER_DEBUG(_logger_sql,
                           "unified_sql:_check_queues   - resources: {}, "
                           "perfdata: {}, metrics: {}, customvar: "
                           "{}, logs: {}, downtimes: {} comments: {}",
@@ -1002,16 +1014,18 @@ void stream::_check_queues(boost::system::error_code ec) {
 
     } catch (const std::exception& e) {
       SPDLOG_LOGGER_ERROR(
-          log_v2::sql(), "fail to store queued data in database: {}", e.what());
+          _logger_sql, "fail to store queued data in database: {}", e.what());
     }
 
     if (!_stop_check_queues) {
-      std::lock_guard<std::mutex> l(_timer_m);
+      absl::MutexLock l(&_timer_m);
       _queues_timer.expires_after(std::chrono::seconds(5));
-      _queues_timer.async_wait(
-          [this](const boost::system::error_code& err) { _check_queues(err); });
+      _queues_timer.async_wait([this](const boost::system::error_code& err) {
+        absl::ReaderMutexLock lck(&_barrier_timer_m);
+        _check_queues(err);
+      });
     } else {
-      SPDLOG_LOGGER_INFO(log_v2::sql(),
+      SPDLOG_LOGGER_INFO(_logger_sql,
                          "SQL: check_queues correctly interrupted.");
       _check_queues_stopped = true;
       _queues_cond_var.notify_all();
@@ -1024,7 +1038,7 @@ void stream::_check_queues(boost::system::error_code ec) {
  */
 void stream::_check_deleted_index() {
   // Info.
-  SPDLOG_LOGGER_INFO(log_v2::sql(), "unified_sql: starting DB cleanup");
+  SPDLOG_LOGGER_INFO(_logger_sql, "unified_sql: starting DB cleanup");
 
   std::promise<database::mysql_result> promise;
   std::future<database::mysql_result> future = promise.get_future();
@@ -1053,15 +1067,15 @@ void stream::_check_deleted_index() {
       metrics_to_delete.insert(res.value_as_u64(0));
     }
   } catch (const std::exception& e) {
-    log_v2::sql()->error(
+    _logger_sql->error(
         "could not query index / metrics table(s) to get index to delete: "
         "{} ",
         e.what());
   }
 
-  SPDLOG_LOGGER_INFO(log_v2::sql(), "Something to remove?");
+  SPDLOG_LOGGER_INFO(_logger_sql, "Something to remove?");
   if (!metrics_to_delete.empty() || !index_to_delete.empty()) {
-    SPDLOG_LOGGER_INFO(log_v2::sql(), "YES!!!");
+    SPDLOG_LOGGER_INFO(_logger_sql, "YES!!!");
     auto rg = std::make_shared<bbdo::pb_remove_graphs>();
     auto& obj = rg->mut_obj();
     for (auto& m : metrics_to_delete)
@@ -1092,13 +1106,13 @@ void stream::_check_rebuild_index() {
     }
 
   } catch (const std::exception& e) {
-    log_v2::sql()->error(
+    _logger_sql->error(
         "could not query indexes table to get indexes to delete: {}", e.what());
   }
 
-  SPDLOG_LOGGER_INFO(log_v2::sql(), "Something to rebuild?");
+  SPDLOG_LOGGER_INFO(_logger_sql, "Something to rebuild?");
   if (!index_to_rebuild.empty()) {
-    SPDLOG_LOGGER_INFO(log_v2::sql(), "YES!!!");
+    SPDLOG_LOGGER_INFO(_logger_sql, "YES!!!");
     auto rg = std::make_shared<bbdo::pb_rebuild_graphs>();
     auto& obj = rg->mut_obj();
     for (auto& i : index_to_rebuild)
