@@ -1,21 +1,21 @@
-/*
-** Copyright 2011-2019,2022 Centreon
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 2011-2019,2022-2024 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ *
+ */
 
 #include "com/centreon/engine/configuration/applier/host.hh"
 
@@ -27,7 +27,6 @@
 #include "com/centreon/engine/downtimes/downtime_manager.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/globals.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/severity.hh"
 
 using namespace com::centreon;
@@ -53,7 +52,7 @@ void applier::host::add_object(configuration::host const& obj) {
   // Logging.
   engine_logger(logging::dbg_config, logging::more)
       << "Creating new host '" << obj.host_name() << "'.";
-  log_v2::config()->debug("Creating new host '{}'.", obj.host_name());
+  config_logger->debug("Creating new host '{}'.", obj.host_name());
 
   // Add host to the global configuration set.
   config->hosts().insert(obj);
@@ -120,15 +119,16 @@ void applier::host::add_object(configuration::host const& obj) {
     h->get_contactgroups().insert({*it, nullptr});
 
   // Custom variables.
-  for (map_customvar::const_iterator it(obj.customvariables().begin()),
-       end(obj.customvariables().end());
+  for (auto it = obj.customvariables().begin(),
+            end = obj.customvariables().end();
        it != end; ++it) {
-    h->custom_variables[it->first] = it->second;
+    h->custom_variables[it->first] =
+        engine::customvariable(it->second.value(), it->second.is_sent());
 
     if (it->second.is_sent()) {
       timeval tv(get_broker_timestamp(nullptr));
       broker_custom_variable(NEBTYPE_HOSTCUSTOMVARIABLE_ADD, h.get(),
-                             it->first.c_str(), it->second.get_value().c_str(),
+                             it->first.c_str(), it->second.value().c_str(),
                              &tv);
     }
   }
@@ -170,53 +170,6 @@ void applier::host::add_object(configuration::host const& obj) {
                             h.get(), MODATTR_ALL);
 }
 
-/**
- *  @brief Expand a host.
- *
- *  During expansion, the host will be added to its host groups. These
- *  will be modified in the state.
- *
- *  @param[int,out] s   Configuration state.
- */
-void applier::host::expand_objects(configuration::state& s) {
-  // Browse all hosts.
-  for (auto& host_cfg : s.hosts()) {
-    // Should custom variables be sent to broker ?
-    for (map_customvar::iterator
-             it(const_cast<map_customvar&>(host_cfg.customvariables()).begin()),
-         end(const_cast<map_customvar&>(host_cfg.customvariables()).end());
-         it != end; ++it) {
-      if (!s.enable_macros_filter() ||
-          s.macros_filter().find(it->first) != s.macros_filter().end()) {
-        it->second.set_sent(true);
-      }
-    }
-
-    // Browse current host's groups.
-    for (set_string::const_iterator it_group(host_cfg.hostgroups().begin()),
-         end_group(host_cfg.hostgroups().end());
-         it_group != end_group; ++it_group) {
-      // Find host group.
-      configuration::set_hostgroup::iterator group(
-          s.hostgroups_find(*it_group));
-      if (group == s.hostgroups().end())
-        throw(engine_error()
-              << "Could not add host '" << host_cfg.host_name()
-              << "' to non-existing host group '" << *it_group << "'");
-
-      // Remove host group from state.
-      configuration::hostgroup backup(*group);
-      s.hostgroups().erase(group);
-
-      // Add host to group members.
-      backup.members().insert(host_cfg.host_name());
-
-      // Reinsert host group.
-      s.hostgroups().insert(backup);
-    }
-  }
-}
-
 /**
  *  Modified host.
  *
@@ -226,7 +179,7 @@ void applier::host::modify_object(configuration::host const& obj) {
   // Logging.
   engine_logger(logging::dbg_config, logging::more)
       << "Modifying host '" << obj.host_name() << "'.";
-  log_v2::config()->debug("Modifying host '{}'.", obj.host_name());
+  config_logger->debug("Modifying host '{}'.", obj.host_name());
 
   // Find the configuration object.
   set_host::iterator it_cfg(config->hosts_find(obj.key()));
@@ -237,8 +190,8 @@ void applier::host::modify_object(configuration::host const& obj) {
   // Find host object.
   host_id_map::iterator it_obj(engine::host::hosts_by_id.find(obj.key()));
   if (it_obj == engine::host::hosts_by_id.end())
-    throw engine_error() << "Could not modify non-existing "
-                         << "host object '" << obj.host_name() << "'";
+    throw engine_error() << "Could not modify non-existing " << "host object '"
+                         << obj.host_name() << "'";
 
   // Update the global configuration set.
   configuration::host obj_old(*it_cfg);
@@ -329,6 +282,7 @@ void applier::host::modify_object(configuration::host const& obj) {
   it_obj->second->set_notes_url(obj.notes_url());
   it_obj->second->set_action_url(obj.action_url());
   it_obj->second->set_icon_image(obj.icon_image());
+  it_obj->second->set_icon_id(obj.icon_id());
   it_obj->second->set_icon_image_alt(obj.icon_image_alt());
   it_obj->second->set_vrml_image(obj.vrml_image());
   it_obj->second->set_statusmap_image(obj.statusmap_image());
@@ -382,19 +336,20 @@ void applier::host::modify_object(configuration::host const& obj) {
         timeval tv(get_broker_timestamp(nullptr));
         broker_custom_variable(NEBTYPE_HOSTCUSTOMVARIABLE_DELETE,
                                it_obj->second.get(), c.first.c_str(),
-                               c.second.get_value().c_str(), &tv);
+                               c.second.value().c_str(), &tv);
       }
     }
     it_obj->second->custom_variables.clear();
 
     for (auto& c : obj.customvariables()) {
-      it_obj->second->custom_variables[c.first] = c.second;
+      it_obj->second->custom_variables[c.first] =
+          engine::customvariable(c.second.value(), c.second.is_sent());
 
       if (c.second.is_sent()) {
         timeval tv(get_broker_timestamp(nullptr));
         broker_custom_variable(NEBTYPE_HOSTCUSTOMVARIABLE_ADD,
                                it_obj->second.get(), c.first.c_str(),
-                               c.second.get_value().c_str(), &tv);
+                               c.second.value().c_str(), &tv);
       }
     }
   }
@@ -420,10 +375,8 @@ void applier::host::modify_object(configuration::host const& obj) {
   if (obj.parents() != obj_old.parents()) {
     // Delete old parents.
     {
-      for (host_map_unsafe::iterator it(it_obj->second->parent_hosts.begin()),
-           end(it_obj->second->parent_hosts.end());
-           it != end; it++)
-        broker_relation_data(NEBTYPE_PARENT_DELETE, it->second, nullptr,
+      for (const auto& [_, sptr_host] : it_obj->second->parent_hosts)
+        broker_relation_data(NEBTYPE_PARENT_DELETE, sptr_host.get(), nullptr,
                              it_obj->second.get(), nullptr);
     }
     it_obj->second->parent_hosts.clear();
@@ -462,7 +415,7 @@ void applier::host::remove_object(configuration::host const& obj) {
   // Logging.
   engine_logger(logging::dbg_config, logging::more)
       << "Removing host '" << obj.host_name() << "'.";
-  log_v2::config()->debug("Removing host '{}'.", obj.host_name());
+  config_logger->debug("Removing host '{}'.", obj.host_name());
 
   // Find host.
   host_id_map::iterator it(engine::host::hosts_by_id.find(obj.key()));
@@ -482,6 +435,11 @@ void applier::host::remove_object(configuration::host const& obj) {
     for (auto& it_h : it->second->get_parent_groups())
       it_h->members.erase(it->second->name());
 
+    // remove any relations
+    for (const auto& [_, sptr_host] : it->second->parent_hosts)
+      broker_relation_data(NEBTYPE_PARENT_DELETE, sptr_host.get(), nullptr,
+                           it->second.get(), nullptr);
+
     // Notify event broker.
     for (auto it_s = it->second->services.begin();
          it_s != it->second->services.end(); ++it_s)
@@ -509,17 +467,15 @@ void applier::host::resolve_object(configuration::host const& obj) {
   // Logging.
   engine_logger(logging::dbg_config, logging::more)
       << "Resolving host '" << obj.host_name() << "'.";
-  log_v2::config()->debug("Resolving host '{}'.", obj.host_name());
+  config_logger->debug("Resolving host '{}'.", obj.host_name());
 
   // If it is the very first host to be resolved,
   // remove all the child backlinks of all the hosts.
   // It is necessary to do it only once to prevent the removal
   // of valid child backlinks.
   if (obj == *config->hosts().begin()) {
-    for (host_map::iterator it(engine::host::hosts.begin()),
-         end(engine::host::hosts.end());
-         it != end; ++it)
-      it->second->child_hosts.clear();
+    for (const auto& [_, sptr_host] : engine::host::hosts)
+      sptr_host->child_hosts.clear();
   }
 
   // Find host.
@@ -541,3 +497,52 @@ void applier::host::resolve_object(configuration::host const& obj) {
   // Resolve host.
   it->second->resolve(config_warnings, config_errors);
 }
+
+/**
+ *  @brief Expand a host.
+ *
+ *  During expansion, the host will be added to its host groups. These
+ *  will be modified in the state.
+ *
+ *  @param[int,out] s   Configuration state.
+ */
+void applier::host::expand_objects(configuration::state& s) {
+  // Browse all hosts.
+  set_host new_hosts;
+  for (auto host_cfg : s.hosts()) {
+    // Should custom variables be sent to broker ?
+    for (auto it = host_cfg.mut_customvariables().begin(),
+              end = host_cfg.mut_customvariables().end();
+         it != end; ++it) {
+      if (!s.enable_macros_filter() ||
+          s.macros_filter().find(it->first) != s.macros_filter().end()) {
+        it->second.set_sent(true);
+      }
+    }
+
+    // Browse current host's groups.
+    for (set_string::const_iterator it_group(host_cfg.hostgroups().begin()),
+         end_group(host_cfg.hostgroups().end());
+         it_group != end_group; ++it_group) {
+      // Find host group.
+      configuration::set_hostgroup::iterator group(
+          s.hostgroups_find(*it_group));
+      if (group == s.hostgroups().end())
+        throw(engine_error()
+              << "Could not add host '" << host_cfg.host_name()
+              << "' to non-existing host group '" << *it_group << "'");
+
+      // Remove host group from state.
+      configuration::hostgroup backup(*group);
+      s.hostgroups().erase(group);
+
+      // Add host to group members.
+      backup.members().insert(host_cfg.host_name());
+
+      // Reinsert host group.
+      s.hostgroups().insert(backup);
+    }
+    new_hosts.insert(host_cfg);
+  }
+  s.hosts() = std::move(new_hosts);
+}
