@@ -1,28 +1,27 @@
-/*
-** Copyright 1999-2010 Ethan Galstad
-** Copyright 2011-2020 Centreon
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 1999-2010 Ethan Galstad
+ * Copyright 2011-2020 Centreon
+ *
+ * This file is part of Centreon Engine.
+ *
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
 
 #include "com/centreon/engine/macros/grab_value.hh"
 
 #include "com/centreon/engine/configuration/applier/state.hh"
 #include "com/centreon/engine/globals.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/macros.hh"
 #include "com/centreon/engine/string.hh"
@@ -339,14 +338,14 @@ static int handle_contact_macro(nagios_macros* mac,
       retval = ERROR;
     else {
       // Concatenate macro values for all contactgroup members.
-      for (contact_map_unsafe::const_iterator
-               it{cg->second->get_members().begin()},
-           end{cg->second->get_members().end()};
+      for (contact_map::const_iterator it = cg->second->get_members().begin(),
+                                       end = cg->second->get_members().end();
            it != end; ++it) {
         if (it->second) {
           // Get the macro value for this contact.
           std::string buffer;
-          grab_standard_contact_macro_r(mac, macro_type, it->second, buffer);
+          grab_standard_contact_macro_r(mac, macro_type, it->second.get(),
+                                        buffer);
           // Add macro value to already running macro.
           if (output.empty())
             output = buffer;
@@ -377,7 +376,7 @@ static int handle_contact_macro(nagios_macros* mac,
  *
  *  @return OK on success.
  */
-static int handle_contactgroup_macro(nagios_macros* mac,
+static int handle_contactgroup_macro(nagios_macros* mac [[maybe_unused]],
                                      int macro_type,
                                      const std::string& arg1,
                                      const std::string& arg2,
@@ -953,7 +952,7 @@ int grab_macro_value_r(nagios_macros* mac,
     if (strcmp(macro_x_names[x].c_str(), buf) == 0) {
       engine_logger(dbg_macros, most)
           << "  macros[" << x << "] (" << macro_x_names[x] << ") match.";
-      log_v2::macros()->trace("  macros[{}] ({}) match.", x, macro_x_names[x]);
+      macros_logger->trace("  macros[{}] ({}) match.", x, macro_x_names[x]);
 
       /* get the macro value */
       result = grab_macrox_value_r(mac, x, arg[0] ? arg[0] : "",
@@ -967,7 +966,7 @@ int grab_macro_value_r(nagios_macros* mac,
         *clean_options |= (STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS);
         engine_logger(dbg_macros, most)
             << "  New clean options: " << *clean_options;
-        log_v2::macros()->trace("  New clean options: {}", *clean_options);
+        macros_logger->trace("  New clean options: {}", *clean_options);
       }
       break;
     }
@@ -981,7 +980,7 @@ int grab_macro_value_r(nagios_macros* mac,
            strncmp(macro_name.c_str(), "ARG", 3) == 0) {
     /* which arg do we want? */
     if (!absl::SimpleAtoi(macro_name.c_str() + 3, &x)) {
-      log_v2::macros()->error(
+      macros_logger->error(
           "Error: could not grab macro value : '{}' must be a positive integer",
           macro_name.c_str() + 3);
       return ERROR;
@@ -1001,7 +1000,7 @@ int grab_macro_value_r(nagios_macros* mac,
            strncmp(macro_name.c_str(), "USER", 4) == 0) {
     /* which macro do we want? */
     if (!absl::SimpleAtoi(macro_name.c_str() + 4, &x)) {
-      log_v2::macros()->error(
+      macros_logger->error(
           "Error: could not grab macro value : '{}' must be a positive integer",
           macro_name.c_str() + 4);
       return ERROR;
@@ -1023,7 +1022,7 @@ int grab_macro_value_r(nagios_macros* mac,
            strncmp(macro_name.c_str(), "CONTACTADDRESS", 14) == 0) {
     /* which address do we want? */
     if (!absl::SimpleAtoi(macro_name.c_str() + 14, &x)) {
-      log_v2::macros()->error(
+      macros_logger->error(
           "Error: could not grab macro value : '{}' must be a positive integer",
           macro_name.c_str() + 14);
       return ERROR;
@@ -1051,15 +1050,15 @@ int grab_macro_value_r(nagios_macros* mac,
           return ERROR;
 
         /* concatenate macro values for all contactgroup members */
-        for (contact_map_unsafe::const_iterator
-                 it{cg_it->second->get_members().begin()},
-             end{cg_it->second->get_members().end()};
+        for (contact_map::const_iterator
+                 it = cg_it->second->get_members().begin(),
+                 end = cg_it->second->get_members().end();
              it != end; ++it) {
           if (!it->second)
             continue;
 
           /* get the macro value for this contact */
-          grab_contact_address_macro(x, it->second, temp_buffer);
+          grab_contact_address_macro(x, it->second.get(), temp_buffer);
 
           if (temp_buffer.empty())
             continue;
@@ -1107,8 +1106,8 @@ int grab_macro_value_r(nagios_macros* mac,
   else {
     engine_logger(dbg_macros, basic)
         << " WARNING: Could not find a macro matching '" << macro_name << "'!";
-    log_v2::macros()->trace(" WARNING: Could not find a macro matching '{}'!",
-                            macro_name);
+    macros_logger->trace(" WARNING: Could not find a macro matching '{}'!",
+                         macro_name);
     result = ERROR;
   }
 
@@ -1146,8 +1145,7 @@ int grab_macrox_value_r(nagios_macros* mac,
       retval = ERROR;
       engine_logger(dbg_macros, basic)
           << "UNHANDLED MACRO #" << macro_type << "! THIS IS A BUG!";
-      log_v2::macros()->trace("UNHANDLED MACRO #{}! THIS IS A BUG!",
-                              macro_type);
+      macros_logger->trace("UNHANDLED MACRO #{}! THIS IS A BUG!", macro_type);
     } else {
       retval = (*it->second)(mac, macro_type, arg1, arg2, output, free_macro);
     }
