@@ -250,6 +250,8 @@ sub routing {
 
         if (defined($register_nodes->{$target})) {
             if ($synctime_nodes->{$target}->{synctime_error} == -1 && get_sync_time(dbh => $options{dbh}, node_id => $target) == -1) {
+                $options{logger}->writeLogDebug("[proxy] ignoring Getlog for '" . $target .
+                    "' because last sync ($synctime_nodes->{$target}->{ctime}) is not finished (expecting $synctime_nodes->{$target}->{got_msg} / $synctime_nodes->{$target}->{total_msg})");
                 gorgone::standard::library::add_history({
                     dbh => $options{dbh},
                     code => GORGONE_ACTION_FINISH_KO, token => $options{token},
@@ -259,7 +261,9 @@ sub routing {
                 return undef;
             }
 
-            if ($synctime_nodes->{$target}->{in_progress} == 1) {
+            if (defined($synctime_nodes->{$target}->{total_msg})) {
+                $options{logger}->writeLogDebug("[proxy] getlog already in progress for '" . $target .
+                    "' last sync ($synctime_nodes->{$target}->{ctime}) is not finished (expecting $synctime_nodes->{$target}->{got_msg} / $synctime_nodes->{$target}->{total_msg})");
                 gorgone::standard::library::add_history({
                     dbh => $options{dbh},
                     code => GORGONE_ACTION_FINISH_KO, token => $options{token},
@@ -269,11 +273,15 @@ sub routing {
                 return undef;
             }
 
-            # We put the good time to get        
+            # We put the good time to get
             my $ctime = $synctime_nodes->{$target}->{ctime};
             $options{frame}->setData({ ctime => $ctime });
             $options{frame}->setRawData();
-            $synctime_nodes->{$target}->{in_progress} = 1;
+            # if total_msg is -1 it mean the query was already sent but no response was received yet.
+            # if total_msg is > 0 it mean we received the first part of the response and waiting for the rest of it.
+            $synctime_nodes->{$target}->{total_msg} = -1;
+            $synctime_nodes->{$target}->{got_msg} = 0;
+            #$synctime_nodes->{$target}->{in_progress} = 1;
             $synctime_nodes->{$target}->{in_progress_time} = time();
         }
     }
@@ -451,15 +459,19 @@ sub check {
             }
         }
 
-        if ($synctime_nodes->{$_}->{in_progress} == 1 && 
+        if (defined($synctime_nodes->{$_}->{total_msg}) &&
             time() - $synctime_nodes->{$_}->{in_progress_time} > $synctimeout_option) {
+            $options{logger}->writeLogInfo("[proxy] Getlog max timeout reached for '" . $_ . "'");
             gorgone::standard::library::add_history({
                 dbh => $options{dbh},
                 code => GORGONE_ACTION_FINISH_KO,
                 data => { message => "proxy - getlog in timeout for '$_'" },
                 json_encode => 1
             });
-            $synctime_nodes->{$_}->{in_progress} = 0;
+            # this property created when querying for node logs, in routing() with GETLOG event.
+            # if the query is in timeout, delete everything to be ready for the next query.
+            delete($synctime_nodes->{$_}->{total_msg});
+            $synctime_nodes->{$_}->{got_msg} = 0
         }
     }
 
@@ -580,30 +592,36 @@ sub pathway {
     # if there are here, we use the first pathway (because all pathways had an issue)
     return (1, 0, $first_target . '~~' . $target, $first_target, $target);
 }
-
+# Store log from a distant poller to local database, and the last log creation time (ctime) to avoid asking the same logs again.
+# called by routing() to process the SETLOGS event.
+# it's a getlog response from a distant node. on single node getlogs are not transformed in setlog.
+# each getlog can generate multiples setlogs depending on the size/number of logs on remote host. (see pullwss::hook::transmit_back)
+# For now if a message is lost during transit it's not asked again.
 sub setlogs {
+    # data: the zmq message received
+    # logger : the logger object
+    # token: unique token for the setlogs operation
+    # dbh: the gorgone internal database handler (sqlite for now)
     my (%options) = @_;
 
     if (!defined($options{data}->{data}->{id}) || $options{data}->{data}->{id} eq '') {
+        $options{logger}->writeLogInfo("[proxy] [$options{token}] Need a id to setlogs");
         gorgone::standard::library::add_history({
-            dbh => $options{dbh},
-            code => GORGONE_ACTION_FINISH_KO, token => $options{token},
-            data => { message => 'proxy - need a id to setlogs' },
-            json_encode => 1
-        });
-        return undef;
-    }
-    if ($synctime_nodes->{ $options{data}->{data}->{id} }->{in_progress} == 0) {
-        gorgone::standard::library::add_history({
-            dbh => $options{dbh},
-            code => GORGONE_ACTION_FINISH_KO, token => $options{token},
-            data => { message => 'proxy - skip setlogs response. Maybe too much time to get response. Retry' },
+            dbh         => $options{dbh},
+            code        => GORGONE_ACTION_FINISH_KO, token => $options{token},
+            data        => { message => 'proxy - need a id to setlogs' },
             json_encode => 1
         });
         return undef;
     }
 
-    $options{logger}->writeLogInfo("[proxy] Received setlogs for '$options{data}->{data}->{id}'");
+    my $node_status = $synctime_nodes->{ $options{data}->{data}->{id} };
+    # log overview of multipart message only if it's a multipart message.
+    my $logline = "";
+    if (defined($options{data}->{data}->{nb_total_msg})) {
+        $logline = " part " . $node_status->{got_msg} . "/" . $options{data}->{data}->{nb_total_msg};
+    }
+    $options{logger}->writeLogInfo("[proxy] Received setlogs for '$options{data}->{data}->{id}'" . $logline);
 
     # we have received the setlogs (it's like a pong response. not a problem if we received the pong after)
     $constatus_ping->{ $options{data}->{data}->{id} }->{in_progress_ping} = 0;
@@ -611,14 +629,21 @@ sub setlogs {
     $constatus_ping->{ $options{data}->{data}->{id} }->{last_ping_recv} = time();
     $last_pong->{ $options{data}->{data}->{id} } = time() if (defined($last_pong->{ $options{data}->{data}->{id} }));
 
-    $synctime_nodes->{ $options{data}->{data}->{id} }->{in_progress} = 0;
+    if (!defined($node_status->{total_msg} or $node_status->{total_msg} == -1)) {
+        $node_status->{total_msg} = $options{data}->{data}->{nb_total_msg} // 1;
+        # if not defined it probably mean we are connected to an older node that does not support multipart messages, so there is only one part.
+    }
 
     my $ctime_recent = 0;
     # Transaction. We don't use last_id (problem if it's clean the sqlite table).
     my $status;
-    $status = $options{dbh}->transaction_mode(1);
-    return -1 if ($status == -1);
+        increment_log_messages_retrieved($node_status, $options{logger}, $options{data}->{data}->{id});
 
+    $status = $options{dbh}->start_transaction();
+    if ($status == -1){
+        $options{logger}->writeLogError("[proxy] setlogs() could not start a transaction to add log in database. Logs are still available on remote host if needed.");
+        return -1;
+    }
     foreach (@{$options{data}->{data}->{result}}) {
         # wrong timestamp inserted. we skip it
         if ($_->{ctime} !~ /[0-9\.]/) {
@@ -637,14 +662,23 @@ sub setlogs {
         $ctime_recent = $_->{ctime} if ($ctime_recent < $_->{ctime});
     }
     if ($status == 0 && update_sync_time(dbh => $options{dbh}, id => $options{data}->{data}->{id}, ctime => $ctime_recent) == 0) {
+        if ($status == -1){
+            $options{logger}->writeLogError("[proxy] setlogs() could not add_history(). Logs are still available on remote host if needed.");
+            last;
+        }
+        $node_status->{ctime}  = $_->{ctime} if ($node_status->{ctime}  < $_->{ctime});
+    }
+    if ($status == 0 && update_sync_time(dbh => $options{dbh}, id => $options{data}->{data}->{id}, ctime => $node_status->{ctime} ) == 0) {
         $status = $options{dbh}->commit();
-        return -1 if ($status == -1);
-        $options{dbh}->transaction_mode(0);
+        if ($status == -1) {
+            $options{logger}->writeLogError("[proxy] setlogs() error updating the lastupdate time. Logs are still available on remote host if needed.");
+            return -1;
+        }
 
-        $synctime_nodes->{ $options{data}->{data}->{id} }->{ctime} = $ctime_recent if ($ctime_recent != 0); 
+        $synctime_nodes->{ $options{data}->{data}->{id} }->{ctime} = $ctime_recent if ($ctime_recent != 0);
     } else {
         $options{dbh}->rollback();
-        $options{dbh}->transaction_mode(0);
+        $options{logger}->writeLogError("[proxy] setlogs() could not update data, doing a rollback. Logs are still available on remote host if needed.");
         return -1;
     }
 
@@ -662,6 +696,25 @@ sub setlogs {
 
     return 0;
 }
+# when retrieving logs from a node, logs can be sent in multiple parts.
+# each part contain the total number of part to expect.
+# this function increment the number of part we got, and delete the hash if we got all the parts.
+# the routing() function check if a node is waiting for logs before sending a new request by checking if total_msg is present.
+sub increment_log_messages_retrieved {
+    my $node = shift;
+    my $logger = shift;
+    my $id = shift;
+
+    return if !defined($node->{total_msg});
+
+    $node->{got_msg}++;
+
+    if ($node->{got_msg} >= $node->{total_msg}) {
+        $logger->writeLogInfo("[proxy] ". ($node->{total_msg} != -1 ? $node->{total_msg} : 1) . " logs parts received for node $id, last log is from $node->{ctime}");
+        delete($node->{total_msg});
+        $node->{got_msg} = 0;
+    }
+}
 
 sub ping_send {
     my (%options) = @_;
@@ -729,11 +782,10 @@ sub get_sync_time {
         $synctime_nodes->{$options{node_id}}->{synctime_error} = -1; 
         return -1;
     }
-
     $synctime_nodes->{$options{node_id}}->{synctime_error} = 0;
     if (my $row = $sth->fetchrow_hashref()) {
         $synctime_nodes->{ $row->{id} }->{ctime} = $row->{ctime};
-        $synctime_nodes->{ $row->{id} }->{in_progress} = 0;
+        delete($synctime_nodes->{ $row->{id} }->{total_msg});
         $synctime_nodes->{ $row->{id} }->{in_progress_time} = -1;
     }
 
@@ -1125,12 +1177,18 @@ sub prepare_remote_copy {
         $owner = $options{data}->{content}->{owner} if (defined($options{data}->{content}->{owner}) && $options{data}->{content}->{owner} ne '');
         my $group;
         $group = $options{data}->{content}->{group} if (defined($options{data}->{content}->{group}) && $options{data}->{content}->{group} ne '');
+        my $mode;
+        $mode = $options{data}->{content}->{mode} if (defined($options{data}->{content}->{mode}) && $options{data}->{content}->{mode} ne '');
         foreach my $file (@inventory) {
             next if ($file eq '.');
             $tar->add_files($file);
             if (defined($owner) || defined($group)) {
                 $tar->chown($file, $owner, $group);
             }
+            if (defined($mode)) {
+                $tar->chmod($file, "$mode");
+            }
+
         }
 
         unless (chdir($options{data}->{content}->{cache_dir})) {
@@ -1169,7 +1227,7 @@ sub prepare_remote_copy {
 
     sysopen(FH, $localsrc, O_RDONLY);
     binmode(FH);
-    my $buffer_size = (defined($config->{buffer_size})) ? $config->{buffer_size} : 500_000;
+    my $buffer_size = (defined($config->{buffer_size})) ? $config->{buffer_size} : 150_000;
     my $buffer;
     while (my $bytes = sysread(FH, $buffer, $buffer_size)) {
         my $action = JSON::XS->new->encode({
@@ -1201,7 +1259,11 @@ sub prepare_remote_copy {
             destination => $dst,
             cache_dir => $options{data}->{content}->{cache_dir},
             owner => $options{data}->{content}->{owner},
-            group => $options{data}->{content}->{group}
+            group => $options{data}->{content}->{group},
+            # We only handle mode for regular files because the permissions of the files
+            # contained in a TAR archive are already managed within the archive
+            $type eq 'regular' ? ( mode => $options{data}->{content}->{mode} // undef )
+                               : ()
         },
         parameters => { no_fork => 1 }
     });
