@@ -1,10 +1,35 @@
+#!/usr/bin/python3
+#
+# Copyright 2023-2024 Centreon
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# For more information : contact@centreon.com
+#
+# This script is a little tcp server working on port 5669. It can simulate
+# a cbd instance. It is useful to test the validity of BBDO packets sent by
+# centengine.
 from robot.api import logger
 from subprocess import getoutput, Popen, DEVNULL
 import re
 import os
 from pwd import getpwnam
+from google.protobuf.json_format import MessageToJson
 import time
+import json
 import psutil
+import random
+import string
 from dateutil import parser
 from datetime import datetime
 import pymysql.cursors
@@ -12,13 +37,11 @@ from robot.libraries.BuiltIn import BuiltIn
 from concurrent import futures
 import grpc
 import grpc_stream_pb2_grpc
-import grpc_stream_pb2
-
 
 
 TIMEOUT = 30
 
-BuiltIn().import_resource('db_variables.robot')
+BuiltIn().import_resource('db_variables.resource')
 DB_NAME_STORAGE = BuiltIn().get_variable_value("${DBName}")
 DB_NAME_CONF = BuiltIn().get_variable_value("${DBNameConf}")
 DB_USER = BuiltIn().get_variable_value("${DBUser}")
@@ -26,6 +49,24 @@ DB_PASS = BuiltIn().get_variable_value("${DBPass}")
 DB_HOST = BuiltIn().get_variable_value("${DBHost}")
 DB_PORT = BuiltIn().get_variable_value("${DBPort}")
 VAR_ROOT = BuiltIn().get_variable_value("${VarRoot}")
+ETC_ROOT = BuiltIn().get_variable_value("${EtcRoot}")
+
+
+def ctn_parse_tests_params():
+    params = os.environ.get("TESTS_PARAMS")
+    if params is not None and len(params) > 4:
+        return json.loads(params)
+    else:
+        return {}
+
+
+TESTS_PARAMS = ctn_parse_tests_params()
+
+
+def ctn_is_using_direct_grpc():
+    default_bbdo_version = TESTS_PARAMS.get("default_bbdo_version")
+    default_transport = TESTS_PARAMS.get("default_transport")
+    return default_bbdo_version is not None and default_transport == "grpc" and default_bbdo_version >= "3.1.0"
 
 
 def ctn_check_connection(port: int, pid1: int, pid2: int):
@@ -78,11 +119,25 @@ def ctn_wait_for_connections(port: int, nb: int, timeout: int = 60):
         estab_port = list(filter(r.match, lst))
         if len(estab_port) >= nb:
             return True
-        time.sleep(5)
+        logger.console(f"Currently {estab_port} connections")
+        time.sleep(2)
     return False
 
 
 def ctn_wait_for_listen_on_range(port1: int, port2: int, prog: str, timeout: int = 30):
+    """Wait that an instance of the given program listens on each port in the
+       given range. On success, the function returns True, if the timeout is
+       reached with some missing instances, it returns False.
+
+    Args:
+        port1: The first port
+        port2: The second port (all the ports p such that port1 <= p <p port2
+               will be tested.
+        prog: The name of the program that should be listening.
+        timeout: A timeout in seconds.
+    Returns:
+        A boolean True on success.
+    """
     port1 = int(port1)
     port2 = int(port2)
     rng = range(port1, port2 + 1)
@@ -146,7 +201,7 @@ def ctn_find_regex_in_log_with_timeout(log: str, date, content, timeout: int):
     limit = time.time() + timeout
     c = ""
     while time.time() < limit:
-        ok, c = ctn_find_in_log(log, date, content, True)
+        ok, c = ctn_find_in_log(log, date, content, regex=True)
         if ok:
             return True, c
         time.sleep(5)
@@ -154,12 +209,13 @@ def ctn_find_regex_in_log_with_timeout(log: str, date, content, timeout: int):
     return False, c
 
 
-def ctn_find_in_log_with_timeout(log: str, date, content, timeout: int):
-
+def ctn_find_in_log_with_timeout(log: str, date, content, timeout: int, **kwargs):
     limit = time.time() + timeout
     c = ""
-    while time.time() < limit:
-        ok, c = ctn_find_in_log(log, date, content, False)
+    kwargs['regex'] = False
+
+    while time.time() <= limit:
+        ok, c = ctn_find_in_log(log, date, content, **kwargs)
         if ok:
             return True
         time.sleep(5)
@@ -170,7 +226,7 @@ def ctn_find_in_log_with_timeout(log: str, date, content, timeout: int):
 def ctn_find_in_log_with_timeout_with_line(log: str, date, content, timeout: int):
     """! search a pattern in log from date param
     @param log: path of the log file
-    @param date: date from witch it begins search
+    @param date: date from which it begins search
     @param content: array of pattern to search
     @param timeout: time out in second
     @return  True/False, array of lines found for each pattern
@@ -178,7 +234,7 @@ def ctn_find_in_log_with_timeout_with_line(log: str, date, content, timeout: int
     limit = time.time() + timeout
     c = ""
     while time.time() < limit:
-        ok, c = ctn_find_in_log(log, date, content, False)
+        ok, c = ctn_find_in_log(log, date, content, regex=False)
         if ok:
             return ok, c
         time.sleep(5)
@@ -186,7 +242,7 @@ def ctn_find_in_log_with_timeout_with_line(log: str, date, content, timeout: int
     return False, None
 
 
-def ctn_find_in_log(log: str, date, content, regex=False):
+def ctn_find_in_log(log: str, date, content, **kwargs):
     """Find content in log file from the given date
 
     Args:
@@ -197,13 +253,18 @@ def ctn_find_in_log(log: str, date, content, regex=False):
     Returns:
         boolean,str: The boolean is True on success, and the string contains the first string not found in logs otherwise.
     """
-    logger.info(f"regex={regex}")
+    verbose = True
+    regex = False
+    if 'verbose' in kwargs:
+        verbose = 'verbose' == 'True'
+    if 'regex' in kwargs:
+        regex = bool(kwargs['regex'])
+
     res = []
 
     try:
-        f = open(log, "r", encoding="latin1")
-        lines = f.readlines()
-        f.close()
+        with open(log, "r") as f:
+            lines = f.readlines()
         idx = ctn_find_line_from(lines, date)
 
         for c in content:
@@ -215,7 +276,8 @@ def ctn_find_in_log(log: str, date, content, regex=False):
                 else:
                     match = c in line
                 if match:
-                    logger.console(f"\"{c}\" found at line {i} from {idx}")
+                    if verbose:
+                        logger.console(f"\"{c}\" found at line {i} from {idx}")
                     found = True
                     res.append(line)
                     break
@@ -363,6 +425,11 @@ def ctn_clear_cache():
     getoutput(f"find {VAR_ROOT} -name '*.cache.*' -delete")
 
 
+def ctn_clear_logs():
+    getoutput(f"rm -rf {VAR_ROOT}/log/centreon-engine/config*")
+    getoutput(f"rm -rf {VAR_ROOT}/log/centreon-broker")
+
+
 def ctn_engine_log_table_duplicate(result: list):
     dup = True
     for i in result:
@@ -543,14 +610,14 @@ def ctn_check_service_resource_status_with_timeout(hostname: str, service_desc:
                 cursor.execute(
                     f"SELECT r.status,r.status_confirmed FROM resources r LEFT JOIN services s ON r.id=s.service_id AND r.parent_id=s.host_id LEFT JOIN hosts h ON s.host_id=h.host_id WHERE h.name='{hostname}' AND s.description='{service_desc}'")
                 result = cursor.fetchall()
-                logger.console(
-                    f"result: {int(result[0]['status'])} status: {int(status)}")
+                if len(result) > 0:
+                    logger.console(f"result: {result}")
                 if len(result) > 0 and result[0]['status'] is not None and int(result[0]['status']) == int(status):
                     logger.console(
                         f"status={result[0]['status']} and status_confirmed={result[0]['status_confirmed']}")
                     if state_type == 'HARD' and int(result[0]['status_confirmed']) == 1:
                         return True
-                    else:
+                    elif state_type == 'SOFT' and int(result[0]['status_confirmed']) == 0:
                         return True
         time.sleep(1)
     return False
@@ -569,8 +636,10 @@ def ctn_check_acknowledgement_with_timeout(hostname: str, service_desc: str, ent
 
         with connection:
             with connection.cursor() as cursor:
+                logger.console(
+                    f"SELECT a.acknowledgement_id, a.state, a.type, a.deletion_time FROM acknowledgements a LEFT JOIN services s ON a.host_id=s.host_id AND a.service_id=s.service_id LEFT join hosts h ON s.host_id=h.host_id WHERE s.description='{service_desc}' AND h.name='{hostname}' AND entry_time >= {entry_time} ORDER BY entry_time DESC")
                 cursor.execute(
-                    f"SELECT a.acknowledgement_id, a.state, a.type, a.deletion_time FROM acknowledgements a LEFT JOIN services s ON a.host_id=s.host_id AND a.service_id=s.service_id LEFT join hosts h ON s.host_id=h.host_id WHERE s.description='{service_desc}' AND h.name='{hostname}' AND entry_time >= {entry_time}")
+                    f"SELECT a.acknowledgement_id, a.state, a.type, a.deletion_time FROM acknowledgements a LEFT JOIN services s ON a.host_id=s.host_id AND a.service_id=s.service_id LEFT join hosts h ON s.host_id=h.host_id WHERE s.description='{service_desc}' AND h.name='{hostname}' AND entry_time >= {entry_time} ORDER BY entry_time DESC")
                 result = cursor.fetchall()
                 if len(result) > 0 and result[0]['state'] is not None and int(result[0]['state']) == int(status) and result[0]['deletion_time'] is None:
                     logger.console(
@@ -584,6 +653,14 @@ def ctn_check_acknowledgement_with_timeout(hostname: str, service_desc: str, ent
 
 
 def ctn_check_acknowledgement_is_deleted_with_timeout(ack_id: int, timeout: int, which='COMMENTS'):
+    """
+    Check if an acknowledgement is deleted in comments, acknowledgements or both
+
+    Args:
+        ack_id (int): The acknowledgement id
+        timeout (int): The timeout in seconds
+        which (str): The table to check. It can be 'comments', 'acknowledgements' or 'BOTH'
+    """
     limit = time.time() + timeout
     while time.time() < limit:
         connection = pymysql.connect(host=DB_HOST,
@@ -599,15 +676,16 @@ def ctn_check_acknowledgement_is_deleted_with_timeout(ack_id: int, timeout: int,
                 cursor.execute(
                     f"SELECT c.deletion_time, a.entry_time, a.deletion_time FROM comments c LEFT JOIN acknowledgements a ON c.host_id=a.host_id AND c.service_id=a.service_id AND c.entry_time=a.entry_time WHERE c.entry_type=4 AND a.acknowledgement_id={ack_id}")
                 result = cursor.fetchall()
-                logger.console(result)
-                if len(result) > 0 and result[0]['deletion_time'] is not None and int(result[0]['deletion_time']) > int(result[0]['entry_time']):
-                    if which == 'BOTH' and not result[0]['a.deletion_time']:
+                if len(result) > 0 and result[0]['deletion_time'] is not None and int(result[0]['deletion_time']) >= int(result[0]['entry_time']):
+                    if which == 'BOTH':
+                        if result[0]['a.deletion_time']:
+                            return True
                         logger.console(
                             f"Acknowledgement {ack_id} is only deleted in comments")
                     else:
                         logger.console(
                             f"Acknowledgement {ack_id} is deleted at {result[0]['deletion_time']}")
-                    return True
+                        return True
         time.sleep(1)
     return False
 
@@ -763,13 +841,14 @@ def ctn_check_ba_status_with_timeout(ba_name: str, status: int, timeout: int):
                                      cursorclass=pymysql.cursors.DictCursor)
         with connection:
             with connection.cursor() as cursor:
+                logger.console(f"SELECT * from mod_bam WHERE name='{ba_name}'")
                 cursor.execute(
                     f"SELECT * FROM mod_bam WHERE name='{ba_name}'")
                 result = cursor.fetchall()
                 logger.console(f"ba: {result[0]}")
                 if len(result) > 0 and result[0]['current_status'] is not None and int(result[0]['current_status']) == int(status):
                     return True
-        time.sleep(5)
+        time.sleep(1)
     return False
 
 
@@ -858,7 +937,7 @@ def ctn_check_downtimes_with_timeout(nb: int, timeout: int):
 #    return False
 
 
-def ctn_check_service_downtime_with_timeout(hostname: str, service_desc: str, enabled, timeout: int):
+def ctn_check_service_downtime_with_timeout(hostname: str, service_desc: str, enabled: int, timeout: int):
     limit = time.time() + timeout
     while time.time() < limit:
         connection = pymysql.connect(host=DB_HOST,
@@ -870,11 +949,19 @@ def ctn_check_service_downtime_with_timeout(hostname: str, service_desc: str, en
 
         with connection:
             with connection.cursor() as cursor:
-                if enabled != '0':
-                    cursor.execute("SELECT s.scheduled_downtime_depth FROM downtimes d INNER JOIN hosts h ON d.host_id=h.host_id INNER JOIN services s ON d.service_id=s.service_id WHERE d.deletion_time is null AND s.description='{}' AND h.name='{}'".format(
-                        service_desc, hostname))
+                first = True
+                if enabled != 0:
+                    if first:
+                        logger.console(
+                            f"SELECT s.scheduled_downtime_depth FROM downtimes d INNER JOIN hosts h ON d.host_id=h.host_id INNER JOIN services s ON d.service_id=s.service_id WHERE d.deletion_time is null AND s.description='{service_desc}' AND h.name='{hostname}'")
+                        first = False
+                    cursor.execute(
+                        f"SELECT s.scheduled_downtime_depth FROM downtimes d INNER JOIN hosts h ON d.host_id=h.host_id INNER JOIN services s ON d.service_id=s.service_id WHERE d.deletion_time is null AND s.description='{service_desc}' AND h.name='{hostname}'")
                     result = cursor.fetchall()
-                    if len(result) == int(enabled) and result[0]['scheduled_downtime_depth'] is not None and result[0]['scheduled_downtime_depth'] == int(enabled):
+                    if len(result) > 0:
+                        logger.console(
+                            f"scheduled_downtime_depth: {result[0]['scheduled_downtime_depth']}")
+                    if len(result) == enabled and result[0]['scheduled_downtime_depth'] is not None and result[0]['scheduled_downtime_depth'] == enabled:
                         return True
                     if (len(result) > 0):
                         logger.console("{} downtimes for serv {} scheduled_downtime_depth={}".format(
@@ -886,7 +973,7 @@ def ctn_check_service_downtime_with_timeout(hostname: str, service_desc: str, en
                     cursor.execute("SELECT s.scheduled_downtime_depth, d.deletion_time, d.downtime_id FROM services s INNER JOIN hosts h on s.host_id = h.host_id LEFT JOIN downtimes d ON s.host_id = d.host_id AND s.service_id = d.service_id WHERE s.description='{}' AND h.name='{}'".format(
                         service_desc, hostname))
                     result = cursor.fetchall()
-                    if len(result) > 0 and result[0]['scheduled_downtime_depth'] is not None and result[0]['scheduled_downtime_depth'] == 0 and (result[0]['downtime_id'] is None or result[0]['deletion_time'] is not None):
+                    if len(result) > 0 and result[0]['scheduled_downtime_depth'] is not None and result[0]['scheduled_downtime_depth'] == 0 and (result[0]['downtime_id'] is not None or result[0]['deletion_time'] is not None):
                         return True
         time.sleep(2)
     return False
@@ -955,7 +1042,7 @@ def ctn_check_service_check_status_with_timeout(hostname: str, service_desc: str
     return False
 
 
-def ctn_check_service_output_resource_status_with_timeout(hostname: str, service_desc: str, timeout: int, min_last_check: int, status: int, status_type: str,  output:str):
+def ctn_check_service_output_resource_status_with_timeout(hostname: str, service_desc: str, timeout: int, min_last_check: int, status: int, status_type: str,  output: str):
     """
     ctn_check_host_output_resource_status_with_timeout
 
@@ -984,7 +1071,7 @@ def ctn_check_service_output_resource_status_with_timeout(hostname: str, service
         with connection:
             with connection.cursor() as cursor:
                 cursor.execute(
-                    f"SELECT r.status, r.status_confirmed, r.output FROM resources r LEFT JOIN services s ON r.id=s.service_id AND r.parent_id=s.host_id JOIN hosts h ON s.host_id=h.host_id WHERE h.name='{hostname}' AND s.description='{service_desc}' AND r.last_check >= {min_last_check}" )
+                    f"SELECT r.status, r.status_confirmed, r.output FROM resources r LEFT JOIN services s ON r.id=s.service_id AND r.parent_id=s.host_id JOIN hosts h ON s.host_id=h.host_id WHERE h.name='{hostname}' AND s.description='{service_desc}' AND r.last_check >= {min_last_check}")
                 result = cursor.fetchall()
                 if len(result) > 0:
                     logger.console(f"result: {result}")
@@ -999,7 +1086,6 @@ def ctn_check_service_output_resource_status_with_timeout(hostname: str, service
     return False
 
 
-
 def ctn_check_host_check_with_timeout(hostname: str, timeout: int, command_line: str):
     limit = time.time() + timeout
     while time.time() < limit:
@@ -1024,6 +1110,7 @@ def ctn_check_host_check_with_timeout(hostname: str, timeout: int, command_line:
         time.sleep(1)
     return False
 
+
 def ctn_check_host_check_status_with_timeout(hostname: str, timeout: int, min_last_check: int, state: int, output: str):
     """
     ctn_check_host_check_status_with_timeout
@@ -1061,7 +1148,7 @@ def ctn_check_host_check_status_with_timeout(hostname: str, timeout: int, min_la
     return False
 
 
-def ctn_check_host_output_resource_status_with_timeout(hostname: str, timeout: int, min_last_check: int, status: int, status_type: str,  output:str):
+def ctn_check_host_output_resource_status_with_timeout(hostname: str, timeout: int, min_last_check: int, status: int, status_type: str,  output: str):
     """
     ctn_check_host_output_resource_status_with_timeout
 
@@ -1089,7 +1176,7 @@ def ctn_check_host_output_resource_status_with_timeout(hostname: str, timeout: i
         with connection:
             with connection.cursor() as cursor:
                 cursor.execute(
-                    f"SELECT r.status, r.status_confirmed, r.output FROM resources r JOIN hosts h ON r.id=h.host_id WHERE h.name='{hostname}' AND r.parent_id=0 AND r.last_check >= {min_last_check}" )
+                    f"SELECT r.status, r.status_confirmed, r.output FROM resources r JOIN hosts h ON r.id=h.host_id WHERE h.name='{hostname}' AND r.parent_id=0 AND r.last_check >= {min_last_check}")
                 result = cursor.fetchall()
                 if len(result) > 0:
                     logger.console(f"result: {result}")
@@ -1144,7 +1231,7 @@ def ctn_delete_service_downtime(hst: str, svc: str):
 
     logger.console(f"delete downtime internal_id={did}")
     cmd = f"[{now}] DEL_SVC_DOWNTIME;{did}\n"
-    f = open(VAR_ROOT + "/lib/centreon-engine/config0/rw/centengine.cmd", "w")
+    f = open(f"{VAR_ROOT}/lib/centreon-engine/config0/rw/centengine.cmd", "w")
     f.write(cmd)
     f.close()
 
@@ -1241,6 +1328,7 @@ def ctn_check_host_severity_with_timeout(host_id: int, severity_id, timeout: int
                     "select sv.id from resources r left join severities sv ON r.severity_id=sv.severity_id where r.parent_id = 0 and r.id={}".format(host_id))
                 result = cursor.fetchall()
                 if len(result) > 0:
+                    logger.console(result)
                     if severity_id == 'None':
                         if result[0]['id'] is None:
                             return True
@@ -1251,6 +1339,20 @@ def ctn_check_host_severity_with_timeout(host_id: int, severity_id, timeout: int
 
 
 def ctn_check_resources_tags_with_timeout(parent_id: int, mid: int, typ: str, tag_ids: list, timeout: int, enabled: bool = True):
+    """
+    check if the tags of a resource are the same as the expected ones
+    Args:
+        parent_id: id of the parent of the resource 0 for hosts
+        mid: id of the resource
+        typ: type of the resource (servicegroup, hostgroup or servicecategory)
+        tag_ids: expected tags ids
+        timeout: timeout in seconds
+        enabled: if True, check if the tags are enabled, otherwise check if they are different
+        Returns: 
+           - enabled = True: True if the tags resource (parent_id, mid) is attached to all tags in tag_ids
+           - enabled = False: True if resource (parent_id, mid) is attached to none tag of tag_ids
+
+    """
     if typ == 'servicegroup':
         t = 0
     elif typ == 'hostgroup':
@@ -1271,29 +1373,35 @@ def ctn_check_resources_tags_with_timeout(parent_id: int, mid: int, typ: str, ta
         with connection:
             with connection.cursor() as cursor:
                 logger.console(
-                    f"select t.id from resources r inner join resources_tags rt on r.resource_id=rt.resource_id inner join tags t on rt.tag_id=t.tag_id WHERE r.id={mid} and r.parent_id={parent_id} and t.type={t}")
+                    f"select t.id from resources r inner join resources_tags rt on r.resource_id=rt.resource_id inner join tags t on rt.tag_id=t.tag_id WHERE r.id={mid} and r.parent_id={parent_id} and t.type={t} and r.enabled=1")
                 cursor.execute(
-                    f"select t.id from resources r inner join resources_tags rt on r.resource_id=rt.resource_id inner join tags t on rt.tag_id=t.tag_id WHERE r.id={mid} and r.parent_id={parent_id} and t.type={t}")
+                    f"select t.id from resources r inner join resources_tags rt on r.resource_id=rt.resource_id inner join tags t on rt.tag_id=t.tag_id WHERE r.id={mid} and r.parent_id={parent_id} and t.type={t} and r.enabled=1")
                 result = cursor.fetchall()
                 logger.console(result)
                 if not enabled:
                     if len(result) == 0:
                         return True
                     else:
+                        found_in_tags_ids = False
                         for r in result:
                             if r['id'] in tag_ids:
                                 logger.console(
                                     "id {} is in tag ids".format(r['id']))
+                                found_in_tags_ids = True
                                 break
-                        return True
-                elif enabled and len(result) > 0:
+                        if not found_in_tags_ids:
+                            return True
+                elif len(result) > 0:
                     if len(result) == len(tag_ids):
+                        equals = True
                         for r in result:
                             if r['id'] not in tag_ids:
                                 logger.console(
                                     "id {} is not in tag ids".format(r['id']))
+                                equals = False
                                 break
-                        return True
+                        if equals:
+                            return True
                     else:
                         logger.console(
                             f"Result and tag_ids should have the same size, moreover 'id' in result should be values of tag_ids, result size = {len(result)} and tag_ids size = {len(tag_ids)} - their content are result: {result} and tag_ids: {tag_ids}")
@@ -1350,7 +1458,11 @@ def ctn_check_number_of_resources_monitored_by_poller_is(poller: int, value: int
 
 def ctn_check_number_of_downtimes(expected: int, start, timeout: int):
     limit = time.time() + timeout
-    d = parser.parse(start).timestamp()
+    try:
+        d = parser.parse(start)
+    except:
+        d = datetime.fromtimestamp(start)
+    d = d.timestamp()
     while time.time() < limit:
         connection = pymysql.connect(host=DB_HOST,
                                      user=DB_USER,
@@ -1360,8 +1472,10 @@ def ctn_check_number_of_downtimes(expected: int, start, timeout: int):
                                      cursorclass=pymysql.cursors.DictCursor)
         with connection:
             with connection.cursor() as cursor:
+                logger.console(
+                    f"SELECT count(*) FROM downtimes WHERE start_time >= {d} AND deletion_time IS NULL")
                 cursor.execute(
-                    "SELECT count(*) FROM downtimes WHERE start_time >= {} AND deletion_time IS NULL".format(d))
+                    f"SELECT count(*) FROM downtimes WHERE start_time >= {d} AND deletion_time IS NULL")
                 result = cursor.fetchall()
                 if len(result) > 0:
                     logger.console(
@@ -1394,8 +1508,13 @@ def ctn_check_number_of_relations_between_hostgroup_and_hosts(hostgroup: int, va
     return False
 
 
-def ctn_check_number_of_relations_between_servicegroup_and_services(servicegroup: int, value: int, timeout: int):
+def ctn_check_number_of_relations_between_servicegroup_and_services(servicegroup: int, value: int, timeout: int, service_group_name: str = None):
     limit = time.time() + timeout
+    request = f"SELECT count(*) from servicegroups s join services_servicegroups sg on s.servicegroup_id = sg.servicegroup_id  WHERE s.servicegroup_id={servicegroup}"
+
+    if service_group_name is not None:
+        request += f" AND name='{service_group_name}'"
+
     while time.time() < limit:
         connection = pymysql.connect(host=DB_HOST,
                                      user=DB_USER,
@@ -1406,8 +1525,7 @@ def ctn_check_number_of_relations_between_servicegroup_and_services(servicegroup
 
         with connection:
             with connection.cursor() as cursor:
-                cursor.execute(
-                    "SELECT count(*) FROM services_servicegroups WHERE servicegroup_id={}".format(servicegroup))
+                cursor.execute(request)
                 result = cursor.fetchall()
                 if len(result) > 0:
                     if int(result[0]['count(*)']) == value:
@@ -1524,6 +1642,14 @@ def ctn_create_bad_queue(filename: str):
     f.close()
 
 
+def ctn_grep(file_path: str, pattern: str):
+    with open(file_path, "r") as file:
+        for line in file:
+            if re.search(pattern, line):
+                return line.strip()
+    return ""
+
+
 def ctn_check_types_in_resources(lst: list):
     connection = pymysql.connect(host=DB_HOST,
                                  user=DB_USER,
@@ -1554,15 +1680,57 @@ def ctn_check_types_in_resources(lst: list):
     return False
 
 
-def ctn_grep(file_path: str, pattern: str):
-    with open(file_path, "r") as file:
-        for line in file:
-            if re.search(pattern, line):
-                return line.strip()
-    return ""
+def ctn_check_host_dependencies(dep_host_id, host_id, dep_period, inherits_parent, notif_fail_opts, exec_fail_opts, timeout=TIMEOUT):
+    limit = time.time() + timeout
+    logger.console(
+        f"SELECT count(*) FROM hosts_hosts_dependencies WHERE dependent_host_id={dep_host_id} AND host_id={host_id} AND dependency_period='{dep_period}' AND inherits_parent={inherits_parent} AND notification_failure_options='{notif_fail_opts}' AND execution_failure_options='{exec_fail_opts}'")
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     autocommit=True,
+                                     cursorclass=pymysql.cursors.DictCursor)
+
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute("SELECT * FROM hosts_hosts_dependencies")
+                result = cursor.fetchall()
+                logger.console(result)
+                cursor.execute(
+                    f"SELECT count(*) FROM hosts_hosts_dependencies WHERE dependent_host_id={dep_host_id} AND host_id={host_id} AND dependency_period='{dep_period}' AND inherits_parent={inherits_parent} AND notification_failure_options='{notif_fail_opts}' AND execution_failure_options='{exec_fail_opts}'")
+                result = cursor.fetchall()
+                logger.console(result)
+                if len(result) > 0 and int(result[0]['count(*)']) > 0:
+                    return True
+                time.sleep(2)
+    return False
 
 
-def ctn_get_version():
+def ctn_check_no_host_dependencies(timeout=TIMEOUT):
+    limit = time.time() + timeout
+    logger.console("SELECT count(*) FROM hosts_hosts_dependencies")
+    while time.time() < limit:
+        connection = pymysql.connect(host=DB_HOST,
+                                     user=DB_USER,
+                                     password=DB_PASS,
+                                     database=DB_NAME_STORAGE,
+                                     charset='utf8mb4',
+                                     autocommit=True,
+                                     cursorclass=pymysql.cursors.DictCursor)
+
+        with connection:
+            with connection.cursor() as cursor:
+                cursor.execute(
+                    "SELECT count(*) FROM hosts_hosts_dependencies")
+                result = cursor.fetchall()
+                if len(result) > 0 and int(result[0]['count(*)']) == 0:
+                    return True
+    return False
+
+
+def ctn_get_collect_version():
     f = open("../CMakeLists.txt", "r")
     lines = f.readlines()
     f.close()
@@ -1624,7 +1792,7 @@ def ctn_get_uid():
 def ctn_set_uid(user_id: int):
     os.setuid(user_id)
 
-    
+
 def ctn_has_file_permissions(path: str, permission: int):
     """! test if file has permission passed in parameter
     it does a AND with permission parameter
@@ -1632,13 +1800,14 @@ def ctn_has_file_permissions(path: str, permission: int):
     @permission mask to test file permission
     @return True if the file has the requested permissions
     """
-    stat_res= os.stat(path)
+    stat_res = os.stat(path)
     if stat_res is None:
         logger.console(f"fail to get permission of {path}")
         return False
     masked = stat_res.st_mode & permission
     return masked == permission
 
+
 def ctn_compare_dot_files(file1: str, file2: str):
     """
     Compare two dot files file1 and file2 after removing the pointer addresses
@@ -1676,7 +1845,8 @@ def ctn_compare_dot_files(file1: str, file2: str):
             return False
     return True
 
-def ctn_create_bbdo_grpc_server(port : int, ):
+
+def ctn_create_bbdo_grpc_server(port: int, ):
     """
     start a bbdo streamming grpc server.
     It answers nothing and simulates proxy behavior when cbd is down
@@ -1689,6 +1859,7 @@ def ctn_create_bbdo_grpc_server(port : int, ):
         """
         bbdo grpc service that does nothing
         """
+
         def exchange(self, request_iterator, context):
             time.sleep(0.01)
             for request in request_iterator:
@@ -1699,12 +1870,115 @@ def ctn_create_bbdo_grpc_server(port : int, ):
     certificate_chain = open('/tmp/server_1234.crt', 'rb').read()
     ca_cert = open('/tmp/ca_1234.crt', 'rb').read()
 
-
     server = grpc.server(futures.ThreadPoolExecutor(max_workers=2))
-    grpc_stream_pb2_grpc.add_centreon_bbdoServicer_to_server(service_implementation(), server)
+    grpc_stream_pb2_grpc.add_centreon_bbdoServicer_to_server(
+        service_implementation(), server)
     creds = grpc.ssl_server_credentials([(private_key, certificate_chain)],
-            root_certificates=ca_cert)
-    
+                                        root_certificates=ca_cert)
+
     server.add_secure_port("0.0.0.0:5669", creds)
     server.start()
     return server
+
+
+def create_random_string(length: int):
+    """
+    create_random_string
+
+    create a string with random char
+    Args:
+        length output string length
+    Returns: a string
+    """
+    letters = string.ascii_lowercase
+    return ''.join(random.choice(letters) for i in range(length))
+
+
+def ctn_create_random_dictionary(nb_entries: int):
+    """
+    create_random_dictionary
+
+    create a dictionary with random keys and random string values
+
+    Args:
+        nb_entries  dictionary size
+    Returns: a dictionary
+    """
+    dict_ret = {}
+    for ii in range(nb_entries):
+        dict_ret[create_random_string(10)] = create_random_string(10)
+
+    return dict_ret
+
+
+def ctn_extract_event_from_lua_log(file_path: str, field_name: str):
+    """
+    extract_event_from_lua_log
+
+    extract a json object from a lua log file 
+    Example: Wed Feb  7 15:30:11 2024: INFO: {"_type":196621, "category":3, "element":13, "resource_metrics":{}
+
+    Args:
+        file1: The first file to compare.
+        file2: The second file to compare.
+
+    Returns: True if they have the same content, False otherwise.
+    """
+
+    with open(file1, "r") as f1:
+        content1 = f1.readlines()
+    with open(file2, "r") as f2:
+        content2 = f2.readlines()
+    r = re.compile(r"(.*) 0x[0-9a-f]+")
+
+    def replace_ptr(line):
+        m = r.match(line)
+        if m:
+            return m.group(1)
+        else:
+            return line
+
+    content1 = list(map(replace_ptr, content1))
+    content2 = list(map(replace_ptr, content2))
+
+    if len(content1) != len(content2):
+        return False
+    for i in range(len(content1)):
+        if content1[i] != content2[i]:
+            logger.console(
+                f"Files are different at line {i + 1}: first => << {content1[i].strip()} >> and second => << {content2[i].strip()} >>")
+            return False
+    return True
+
+
+def ctn_protobuf_to_json(protobuf_obj):
+    """
+    protobuf_to_json
+
+    Convert a protobuf object to json
+    it replaces uppercase letters in keys by _<lower>
+    """
+    converted = MessageToJson(protobuf_obj)
+    return json.loads(converted)
+
+
+def ctn_compare_string_with_file(string_to_compare: str, file_path: str):
+    """
+    ctn_compare_string_with_file
+
+    compare a multiline string with a file content
+    Args:
+        string_to_compare: multiline string to compare
+        file_path: path of the file to compare
+
+    Returns: True if contents are identical
+    """
+    str_lines = string_to_compare.splitlines(keepends=True)
+    with open(file_path) as f:
+        file_lines = f.readlines()
+    if len(str_lines) != len(file_lines):
+        return False
+    for str_line, file_line in zip(str_lines, file_lines):
+        if str_line != file_line:
+            return False
+    return True
